searchData={"items":[{"type":"module","title":"prometheus","doc":"","ref":"prometheus.html"},{"type":"function","title":"prometheus.start/2","doc":"","ref":"prometheus.html#start/2"},{"type":"function","title":"prometheus.stop/1","doc":"","ref":"prometheus.html#stop/1"},{"type":"type","title":"prometheus.buckets/0","doc":"","ref":"prometheus.html#t:buckets/0"},{"type":"type","title":"prometheus.counter/0","doc":"","ref":"prometheus.html#t:counter/0"},{"type":"type","title":"prometheus.gauge/0","doc":"","ref":"prometheus.html#t:gauge/0"},{"type":"type","title":"prometheus.histogram/0","doc":"","ref":"prometheus.html#t:histogram/0"},{"type":"type","title":"prometheus.label/0","doc":"","ref":"prometheus.html#t:label/0"},{"type":"type","title":"prometheus.label_name/0","doc":"","ref":"prometheus.html#t:label_name/0"},{"type":"type","title":"prometheus.label_value/0","doc":"","ref":"prometheus.html#t:label_value/0"},{"type":"type","title":"prometheus.labels/0","doc":"","ref":"prometheus.html#t:labels/0"},{"type":"type","title":"prometheus.metrics/0","doc":"","ref":"prometheus.html#t:metrics/0"},{"type":"type","title":"prometheus.pbool/0","doc":"","ref":"prometheus.html#t:pbool/0"},{"type":"type","title":"prometheus.pre_rendered_labels/0","doc":"","ref":"prometheus.html#t:pre_rendered_labels/0"},{"type":"type","title":"prometheus.prometheus_boolean/0","doc":"","ref":"prometheus.html#t:prometheus_boolean/0"},{"type":"type","title":"prometheus.summary/0","doc":"","ref":"prometheus.html#t:summary/0"},{"type":"type","title":"prometheus.tmetric/0","doc":"","ref":"prometheus.html#t:tmetric/0"},{"type":"type","title":"prometheus.untyped/0","doc":"","ref":"prometheus.html#t:untyped/0"},{"type":"type","title":"prometheus.value/0","doc":"","ref":"prometheus.html#t:value/0"},{"type":"module","title":"prometheus_buckets","doc":"","ref":"prometheus_buckets.html"},{"type":"function","title":"prometheus_buckets.default/0","doc":"Default histogram buckets.\n\n```erlang\n1> prometheus_buckets:default().\n[0.005, 0.01, 0.025, 0.05, 0.1, 0.25, 0.5, 1, 2.5, 5, 10]\n\n```\n\nPlease note these buckets are floats and represent seconds so you'll have to use\n`prometheus_histogramdobserve/3` or configure `duration_unit` as `seconds`.","ref":"prometheus_buckets.html#default/0"},{"type":"function","title":"prometheus_buckets.exponential/3","doc":"Creates `Count` buckets, where the lowest bucket has an upper bound of `Start` and each following\nbucket's upper bound is `Factor` times the previous bucket's upper bound.\nThe returned list is meant to be used for the `buckets` key of histogram constructors options.\n\n```erlang\n3> prometheus_buckets:exponential(100, 1.2, 3).\n[100, 120, 144]\n```\n\nThe function raises `{invalid_value, Value, Message}` error if `Count` isn't positive,\nif `Start` isn't positive, or if `Factor` is less than or equals to 1.","ref":"prometheus_buckets.html#exponential/3"},{"type":"function","title":"prometheus_buckets.linear/3","doc":"Creates `Count` buckets, each `Width` wide, where the lowest bucket has an upper bound of `Start`.\n\nThe returned list is meant to be used for the `buckets` key of histogram constructors options.\n\n```erlang\n2> prometheus_buckets:linear(10, 5, 6).\n[10, 15, 20, 25, 30, 35]\n```\n\nThe function raises `{invalid_value, Value, Message}` error if `Count` is zero or negative.","ref":"prometheus_buckets.html#linear/3"},{"type":"function","title":"prometheus_buckets.new/0","doc":"Histogram buckets constructor, returns `default/0` plus `infinity`","ref":"prometheus_buckets.html#new/0"},{"type":"function","title":"prometheus_buckets.new/1","doc":"Histogram buckets constructor","ref":"prometheus_buckets.html#new/1"},{"type":"function","title":"prometheus_buckets.position/2","doc":"","ref":"prometheus_buckets.html#position/2"},{"type":"type","title":"prometheus_buckets.bucket_bound/0","doc":"","ref":"prometheus_buckets.html#t:bucket_bound/0"},{"type":"type","title":"prometheus_buckets.buckets/0","doc":"","ref":"prometheus_buckets.html#t:buckets/0"},{"type":"type","title":"prometheus_buckets.config/0","doc":"Histogram buckets configuration.\n\nSetting the `buckets` key of a histogram to\n- `default`: will use the default buckets\n- `linear`: will use `Start`, `Step`, and `Count` to generate the buckets as in `linear/3`\n- `exponential`: will use `Start`, `Factor`, and `Count` to generate the buckets as in `exponential/3`\n\nYou can also specify your own buckets if desired instead.","ref":"prometheus_buckets.html#t:config/0"},{"type":"behaviour","title":"prometheus_collector","doc":"A collector for a set of metrics.\n\nNormal users should use `m:prometheus_gauge`, `m:prometheus_counter`,\n`m:prometheus_summary` and `m:prometheus_histogram`.\n\nImplementing `prometheus_collector` behaviour is for advanced uses such as proxying\nmetrics from another monitoring system. It is it the responsibility of the implementer\nto ensure produced metrics are valid.\n\nYou will be working with Prometheus data model directly (see `m:prometheus_model_helpers`).","ref":"prometheus_collector.html"},{"type":"behaviour","title":"Example (simplified `prometheus_vm_memory_collector`): - prometheus_collector","doc":"```erlang\n-module(prometheus_vm_memory_collector).\n\n-export([deregister_cleanup/1, collect_mf/2, collect_metrics/2]).\n\n-behaviour(prometheus_collector).\n\n%%====================================================================\n%% Collector API\n%%====================================================================\n\nderegister_cleanup(_) -> ok.\n\ncollect_mf(_Registry, Callback) ->\n    Memory = erlang:memory(),\n    Callback(create_gauge(erlang_vm_bytes_total,\n                          \\\"The total amount of memory currently allocated. \\\"\n                          \\\"This is the same as the sum of the memory size \\\"\n                          \\\"for processes and system.\\\",\n                          Memory)),\n    ok.\n\ncollect_metrics(erlang_vm_bytes_total, Memory) ->\n    prometheus_model_helpers:gauge_metrics(\n      [\n        {[{kind, system}], proplists:get_value(system,  Memory)},\n        {[{kind, processes}], proplists:get_value(processes, Memory)}\n      ]).\n\n%%====================================================================\n%% Private Parts\n%%====================================================================\n\ncreate_gauge(Name, Help, Data) ->\n    prometheus_model_helpers:create_mf(Name, Help, gauge, ?MODULE, Data).\n\n```","ref":"prometheus_collector.html#module-example-simplified-prometheus_vm_memory_collector"},{"type":"callback","title":"prometheus_collector.collect_metrics/2","doc":"Should return Metric list for each MetricFamily identified by `Name`.\n\n`Data` is a term associated with MetricFamily by `c:collect_mf/2`.","ref":"prometheus_collector.html#c:collect_metrics/2"},{"type":"callback","title":"prometheus_collector.collect_mf/2","doc":"Should call `Callback` for each `MetricFamily` of this collector","ref":"prometheus_collector.html#c:collect_mf/2"},{"type":"function","title":"prometheus_collector.collect_mf/3","doc":"Calls `Callback` for each MetricFamily of this collector.","ref":"prometheus_collector.html#collect_mf/3"},{"type":"callback","title":"prometheus_collector.deregister_cleanup/1","doc":"Called when collector is deregistered. If collector is stateful you can put cleanup code here","ref":"prometheus_collector.html#c:deregister_cleanup/1"},{"type":"type","title":"prometheus_collector.collect_mf_callback/0","doc":"Callback for `collect_mf/3`","ref":"prometheus_collector.html#t:collect_mf_callback/0"},{"type":"type","title":"prometheus_collector.collector/0","doc":"Represents a Prometheus collector","ref":"prometheus_collector.html#t:collector/0"},{"type":"type","title":"prometheus_collector.data/0","doc":"Data associated with a collector","ref":"prometheus_collector.html#t:data/0"},{"type":"behaviour","title":"prometheus_format","doc":"Module that implements this behaviour can be used as `foramt` parameter for exporters.\n\nBuilt-in formats:\n- `m:prometheus_text_format`\n- `m:prometheus_protobuf_format`","ref":"prometheus_format.html"},{"type":"callback","title":"prometheus_format.content_type/0","doc":"Should return content type of the format.","ref":"prometheus_format.html#c:content_type/0"},{"type":"callback","title":"prometheus_format.format/0","doc":"Should format `default` registry.","ref":"prometheus_format.html#c:format/0"},{"type":"callback","title":"prometheus_format.format/1","doc":"Should format `Registry`.","ref":"prometheus_format.html#c:format/1"},{"type":"behaviour","title":"prometheus_instrumenter","doc":"","ref":"prometheus_instrumenter.html"},{"type":"callback","title":"prometheus_instrumenter.setup_instrumenter/0","doc":"","ref":"prometheus_instrumenter.html#c:setup_instrumenter/0"},{"type":"type","title":"prometheus_instrumenter.instrumenter/0","doc":"","ref":"prometheus_instrumenter.html#t:instrumenter/0"},{"type":"behaviour","title":"prometheus_metric","doc":"This module provides functions and types for managing Prometheus metrics in Erlang.\n\nIt includes functionality for inserting, deregistering, and checking metrics,\nas well as handling metric labels and data.","ref":"prometheus_metric.html"},{"type":"callback","title":"prometheus_metric.declare/1","doc":"Inserts a new metric function into the table.","ref":"prometheus_metric.html#c:declare/1"},{"type":"callback","title":"prometheus_metric.new/1","doc":"Inserts a new metric function into the table, fails if it already exists.","ref":"prometheus_metric.html#c:new/1"},{"type":"callback","title":"prometheus_metric.remove/1","doc":"Removes a metric function by name.","ref":"prometheus_metric.html#c:remove/1"},{"type":"callback","title":"prometheus_metric.remove/2","doc":"Removes a metric function by name and label values.","ref":"prometheus_metric.html#c:remove/2"},{"type":"callback","title":"prometheus_metric.remove/3","doc":"Removes a metric function by registry, name, and label values.","ref":"prometheus_metric.html#c:remove/3"},{"type":"callback","title":"prometheus_metric.reset/1","doc":"Resets a metric function by name.","ref":"prometheus_metric.html#c:reset/1"},{"type":"callback","title":"prometheus_metric.reset/2","doc":"Resets a metric function by name and label values.","ref":"prometheus_metric.html#c:reset/2"},{"type":"callback","title":"prometheus_metric.reset/3","doc":"Resets a metric function by registry, name, and label values.","ref":"prometheus_metric.html#c:reset/3"},{"type":"callback","title":"prometheus_metric.set_default/2","doc":"Sets the default metric function for the module.","ref":"prometheus_metric.html#c:set_default/2"},{"type":"callback","title":"prometheus_metric.value/1","doc":"Gets the value of a metric function by name.","ref":"prometheus_metric.html#c:value/1"},{"type":"callback","title":"prometheus_metric.value/2","doc":"Gets the value of a metric function by name and label values.","ref":"prometheus_metric.html#c:value/2"},{"type":"callback","title":"prometheus_metric.value/3","doc":"Gets the value of a metric function by registry, name, and label values.","ref":"prometheus_metric.html#c:value/3"},{"type":"type","title":"prometheus_metric.counter_value/0","doc":"Metric counter type","ref":"prometheus_metric.html#t:counter_value/0"},{"type":"type","title":"prometheus_metric.duration_unit/0","doc":"Metric duration unit type","ref":"prometheus_metric.html#t:duration_unit/0"},{"type":"type","title":"prometheus_metric.gauge_value/0","doc":"Metric gauge type","ref":"prometheus_metric.html#t:gauge_value/0"},{"type":"type","title":"prometheus_metric.help/0","doc":"Metric help type","ref":"prometheus_metric.html#t:help/0"},{"type":"type","title":"prometheus_metric.histogram_value/0","doc":"Metric histogram type","ref":"prometheus_metric.html#t:histogram_value/0"},{"type":"type","title":"prometheus_metric.labels/0","doc":"Metric labels type","ref":"prometheus_metric.html#t:labels/0"},{"type":"type","title":"prometheus_metric.name/0","doc":"Metric name type","ref":"prometheus_metric.html#t:name/0"},{"type":"type","title":"prometheus_metric.spec/0","doc":"Metric specification type","ref":"prometheus_metric.html#t:spec/0"},{"type":"type","title":"prometheus_metric.summary_value/0","doc":"Metric summary type","ref":"prometheus_metric.html#t:summary_value/0"},{"type":"type","title":"prometheus_metric.value/0","doc":"Metric value type","ref":"prometheus_metric.html#t:value/0"},{"type":"module","title":"prometheus_registry","doc":"A registry of Collectors.\n\nThe majority of users should use the `default`, rather than their own.\n\nCreating a registry other than the default is primarily useful for unit tests,\nor pushing a subset of metrics to the [Pushgateway](https://github.com/prometheus/pushgateway)\nfrom batch jobs.","ref":"prometheus_registry.html"},{"type":"function","title":"prometheus_registry.clear/0","doc":"","ref":"prometheus_registry.html#clear/0"},{"type":"function","title":"prometheus_registry.clear/1","doc":"Unregisters all collectors.","ref":"prometheus_registry.html#clear/1"},{"type":"function","title":"prometheus_registry.collect/2","doc":"Calls `Callback` for each collector with two arguments: `Registry` and `Collector`.","ref":"prometheus_registry.html#collect/2"},{"type":"function","title":"prometheus_registry.collector_registeredp/1","doc":"","ref":"prometheus_registry.html#collector_registeredp/1"},{"type":"function","title":"prometheus_registry.collector_registeredp/2","doc":"Checks whether `Collector` is registered.","ref":"prometheus_registry.html#collector_registeredp/2"},{"type":"function","title":"prometheus_registry.collectors/1","doc":"Returns collectors registered in `Registry`.","ref":"prometheus_registry.html#collectors/1"},{"type":"function","title":"prometheus_registry.deregister_collector/1","doc":"","ref":"prometheus_registry.html#deregister_collector/1"},{"type":"function","title":"prometheus_registry.deregister_collector/2","doc":"Unregisters a collector.","ref":"prometheus_registry.html#deregister_collector/2"},{"type":"function","title":"prometheus_registry.exists/1","doc":"Tries to find registry with the `Name`.\n\nAssumes that registry name is always an atom.\n- If `Name` is an atom `ets:lookup/2` is used\n- If `Name` is an iolist performs safe search (to avoid interning atoms) and returns atom or false.\n\nThis operation is O(n).","ref":"prometheus_registry.html#exists/1"},{"type":"function","title":"prometheus_registry.register_collector/1","doc":"","ref":"prometheus_registry.html#register_collector/1"},{"type":"function","title":"prometheus_registry.register_collector/2","doc":"Register a collector.","ref":"prometheus_registry.html#register_collector/2"},{"type":"function","title":"prometheus_registry.register_collectors/1","doc":"","ref":"prometheus_registry.html#register_collectors/1"},{"type":"function","title":"prometheus_registry.register_collectors/2","doc":"Registers collectors list.","ref":"prometheus_registry.html#register_collectors/2"},{"type":"type","title":"prometheus_registry.collect_callback/0","doc":"","ref":"prometheus_registry.html#t:collect_callback/0"},{"type":"type","title":"prometheus_registry.registry/0","doc":"","ref":"prometheus_registry.html#t:registry/0"},{"type":"module","title":"prometheus_time","doc":"Measuring time intervals with Prometheus.erl.\nMeasuring time intervals is trivial - you just have to be sure you are using monotonic time source.\nBasically interval is a difference between start time and end time.\nErlang has the standard `erlang:monotonic_time/0` function that returns so called native time units.\nNative time units are meaningless and have to be converted to seconds (or other units) using\n`erlang:convert_time_unit/3`.\nHowever as `erlang:convert_time_unit/3` documentation\n[warns](http://erlang.org/doc/man/erlang.html#convert_time_unit-3):\n\n> You may lose accuracy and precision when converting between  time units.\n> In order to minimize such loss, collect all data at native time unit and\n> do the conversion on the end result.\n\nand because Prometheus mandates support for floats, `set_duration/observe_duration` functions\nalways work with native time units and conversion is delayed until scraping/retrieving value.\nTo implement this, metric needs to know desired time unit.\nUsers can specify time unit explicitly via `duration_unit` or implicitly via metric name\n(preferred, since prometheus best practices guide insists on ` _duration_ `\n metric name format).\n\nPossible units:\n- microseconds;\n- milliseconds;\n- seconds;\n- minutes;\n- hours;\n- days;\n\nHistogram also converts buckets bounds to native units if duration_unit is provided.\nIt converts it back when scraping or retrieving value.\n\nIf values already converted to a 'real' unit,\nconversion can be disabled by setting `duration_unit` to `false`.","ref":"prometheus_time.html"},{"type":"module","title":"Examples - prometheus_time","doc":"Example where duration unit derived from name:\n\n```erlang\nprometheus_histogram:new([{name, fun_duration_seconds},\n                            {buckets, [0.5, 1.1]}, %% in seconds\n                            {help, \"\"}]),\nprometheus_histogram:observe_duration(fun_duration_seconds,\n                                        fun () ->\n                                            timer:sleep(1000)\n                                        end),\nprometheus_histogram:value(fun_duration_seconds).\n{[0,1,0],1.001030886}\n```\n\nExample where duration unit set explicitly:\n\n```erlang\nprometheus_histogram:new([{name, fun_duration_histogram},\n                            {buckets, [500, 1100]}, %% in milliseconds\n                            {help, \"\"},\n                            {duration_unit, milliseconds}]),\n\nprometheus_histogram:observe_duration(fun_duration_histogram,\n                                        fun () ->\n                                            timer:sleep(1000)\n                                        end),\n\nprometheus_histogram:value(fun_duration_histogram).\n{[0,1,0],1001.885302}\n```\n\nExample where value is in seconds already:\n\n```erlang\nprometheus_histogram:new([{name, duration_seconds},\n                            {buckets, [0.5, 1.1]}, %% in seconds\n                            {help, \"\"},\n                            {duration_unit, false}]),\n\nprometheus_histogram:dobserve(duration_seconds, 1.2),\n\nprometheus_histogram:value(duration_seconds).\n{[0,0,1],1.2}\n```","ref":"prometheus_time.html#module-examples"},{"type":"function","title":"prometheus_time.duration_unit_from_string/1","doc":"","ref":"prometheus_time.html#duration_unit_from_string/1"},{"type":"function","title":"prometheus_time.maybe_convert_to_du/2","doc":"","ref":"prometheus_time.html#maybe_convert_to_du/2"},{"type":"function","title":"prometheus_time.maybe_convert_to_native/2","doc":"","ref":"prometheus_time.html#maybe_convert_to_native/2"},{"type":"function","title":"prometheus_time.validate_duration_unit/1","doc":"","ref":"prometheus_time.html#validate_duration_unit/1"},{"type":"type","title":"prometheus_time.duration_unit/0","doc":"","ref":"prometheus_time.html#t:duration_unit/0"},{"type":"type","title":"prometheus_time.maybe_duration_unit/0","doc":"","ref":"prometheus_time.html#t:maybe_duration_unit/0"},{"type":"module","title":"prometheus_model_helpers","doc":"Helpers for working with Prometheus data model. For advanced users.\n\nProbably will be used with `m:prometheus_collector`.","ref":"prometheus_model_helpers.html"},{"type":"function","title":"prometheus_model_helpers.boolean_metric/1","doc":"","ref":"prometheus_model_helpers.html#boolean_metric/1"},{"type":"function","title":"prometheus_model_helpers.boolean_metric/2","doc":"Creates boolean metric with `Labels` and `Value`.","ref":"prometheus_model_helpers.html#boolean_metric/2"},{"type":"function","title":"prometheus_model_helpers.boolean_metrics/1","doc":"","ref":"prometheus_model_helpers.html#boolean_metrics/1"},{"type":"function","title":"prometheus_model_helpers.counter_metric/1","doc":"","ref":"prometheus_model_helpers.html#counter_metric/1"},{"type":"function","title":"prometheus_model_helpers.counter_metric/2","doc":"Creates counter metric with `Labels` and `Value`.","ref":"prometheus_model_helpers.html#counter_metric/2"},{"type":"function","title":"prometheus_model_helpers.counter_metrics/1","doc":"","ref":"prometheus_model_helpers.html#counter_metrics/1"},{"type":"function","title":"prometheus_model_helpers.create_mf/4","doc":"Create Metric Family of `Type`, `Name` and `Help`.\n\n`Collector:collect_metrics/2` callback will be called and expected to return individual metrics list.","ref":"prometheus_model_helpers.html#create_mf/4"},{"type":"function","title":"prometheus_model_helpers.create_mf/5","doc":"Create Metric Family of `Type`, `Name` and `Help`.\n\n`Collector:collect_metrics/2` callback will be called and expected to return individual metrics list.","ref":"prometheus_model_helpers.html#create_mf/5"},{"type":"function","title":"prometheus_model_helpers.gauge_metric/1","doc":"","ref":"prometheus_model_helpers.html#gauge_metric/1"},{"type":"function","title":"prometheus_model_helpers.gauge_metric/2","doc":"Creates gauge metric with `Labels` and `Value`.","ref":"prometheus_model_helpers.html#gauge_metric/2"},{"type":"function","title":"prometheus_model_helpers.gauge_metrics/1","doc":"","ref":"prometheus_model_helpers.html#gauge_metrics/1"},{"type":"function","title":"prometheus_model_helpers.histogram_metric/1","doc":"","ref":"prometheus_model_helpers.html#histogram_metric/1"},{"type":"function","title":"prometheus_model_helpers.histogram_metric/3","doc":"","ref":"prometheus_model_helpers.html#histogram_metric/3"},{"type":"function","title":"prometheus_model_helpers.histogram_metric/4","doc":"Creates histogram metric with `Labels`, `Buckets`, `Count` and `Sum`.","ref":"prometheus_model_helpers.html#histogram_metric/4"},{"type":"function","title":"prometheus_model_helpers.histogram_metrics/1","doc":"","ref":"prometheus_model_helpers.html#histogram_metrics/1"},{"type":"function","title":"prometheus_model_helpers.label_pair/1","doc":"Creates `prometheus_model:`LabelPair'()' from \\{Name, Value\\} tuple.","ref":"prometheus_model_helpers.html#label_pair/1"},{"type":"function","title":"prometheus_model_helpers.label_pairs/1","doc":"Label pairs sequentially.\n\nNB `is_binary' clause here is for a special optimization for text\nformat only: client code can pre-generate final labels string,\ne.g. when it knows when character escaping is not needed. This\navoids direct performance cost of character escaping, and also\nreduces garabage collection pressure, as intermediate lists of\ntuples/records are not created at all. This optimization is used by\nRabbitMQ prometheus plugin (which calls `create_mf/5', and it ends\nhere).\n\nWARNING Works only for text format, protobuf format export will\nfail with an error.","ref":"prometheus_model_helpers.html#label_pairs/1"},{"type":"function","title":"prometheus_model_helpers.metric_name/1","doc":"If `Name` is a list, looks for atoms and converts them to binaries. Why iolists do not support atoms?","ref":"prometheus_model_helpers.html#metric_name/1"},{"type":"function","title":"prometheus_model_helpers.summary_metric/1","doc":"","ref":"prometheus_model_helpers.html#summary_metric/1"},{"type":"function","title":"prometheus_model_helpers.summary_metric/2","doc":"","ref":"prometheus_model_helpers.html#summary_metric/2"},{"type":"function","title":"prometheus_model_helpers.summary_metric/3","doc":"","ref":"prometheus_model_helpers.html#summary_metric/3"},{"type":"function","title":"prometheus_model_helpers.summary_metric/4","doc":"Creates summary metric with `Labels`, `Count` and `Sum`.","ref":"prometheus_model_helpers.html#summary_metric/4"},{"type":"function","title":"prometheus_model_helpers.summary_metrics/1","doc":"","ref":"prometheus_model_helpers.html#summary_metrics/1"},{"type":"function","title":"prometheus_model_helpers.untyped_metric/1","doc":"","ref":"prometheus_model_helpers.html#untyped_metric/1"},{"type":"function","title":"prometheus_model_helpers.untyped_metric/2","doc":"Creates untyped metric with `Labels` and `Value`.","ref":"prometheus_model_helpers.html#untyped_metric/2"},{"type":"function","title":"prometheus_model_helpers.untyped_metrics/1","doc":"","ref":"prometheus_model_helpers.html#untyped_metrics/1"},{"type":"module","title":"prometheus_mnesia_collector","doc":"Collects Mnesia metrics mainly using `mnesia:system_info/1`.","ref":"prometheus_mnesia_collector.html"},{"type":"module","title":"Exported metrics - prometheus_mnesia_collector","doc":"* `erlang_mnesia_held_locks`\n  Type: gauge.\n  Number of held locks.\n* `erlang_mnesia_lock_queue`\n  Type: gauge.\n  Number of transactions waiting for a lock.\n* `erlang_mnesia_transaction_participants`\n  Type: gauge.\n  Number of participant transactions.\n* `erlang_mnesia_transaction_coordinators`\n  Type: gauge.\n  Number of coordinator transactions.\n* `erlang_mnesia_failed_transactions`\n  Type: counter.\n  Number of failed (i.e. aborted) transactions.\n* `erlang_mnesia_committed_transactions`\n  Type: gauge.\n  Number of committed transactions.\n* `erlang_mnesia_logged_transactions`\n  Type: counter.\n  Number of transactions logged.\n* `erlang_mnesia_restarted_transactions`\n  Type: counter.\n  Total number of transaction restarts.\n* `erlang_mnesia_memory_usage_bytes`\n  Type: gauge.\n  Total number of bytes allocated by all mnesia tables.\n* `erlang_mnesia_tablewise_memory_usage_bytes'\n  Type: gauge.\n  Number of bytes allocated per mnesia table\n* `erlang_mnesia_tablewise_size'\n  Type: gauge.\n  Number of rows present per table","ref":"prometheus_mnesia_collector.html#module-exported-metrics"},{"type":"module","title":"Configuration - prometheus_mnesia_collector","doc":"Metrics exported by this collector can be configured via `mnesia_collector_metrics` key\nof the `prometheus` app environment.\n\nAvailable options:\n- `held_locks` for `erlang_mnesia_held_locks`;\n- `lock_queue` for `erlang_mnesia_lock_queue`;\n- `transaction_participants` for `erlang_mnesia_transaction_participants`;\n- `transaction_coordinators` for `erlang_mnesia_transaction_coordinators`;\n- `transaction_failures` for `erlang_mnesia_failed_transactions`;\n- `transaction_commits` for `erlang_mnesia_committed_transactions`;\n- `transaction_log_writes` for `erlang_mnesia_logged_transactions`;\n- `transaction_restarts` for `erlang_mnesia_restarted_transactions`;\n- `memory_usage_bytes` for `erlang_mnesia_memory_usage_bytes`.\n\nBy default all metrics are enabled.","ref":"prometheus_mnesia_collector.html#module-configuration"},{"type":"module","title":"prometheus_vm_dist_collector","doc":"Collects information about the sockets and processes involved in the Erlang distribution mechanism.\n\nAll metrics include a label 'peer' that indicates which distributed connection the metric is about.","ref":"prometheus_vm_dist_collector.html"},{"type":"module","title":"Exported metrics - prometheus_vm_dist_collector","doc":"Metrics pertaining to processes may apply to three different types of processes depending on\nthe distribution transport: `type=\\\"dist\\\"`, `type=\\\"tls_connection\\\"` or `type=\\\"tls_sender\\\"`.\n\n* `erlang_vm_dist_recv_bytes`\n  Type: gauge.\n  Number of bytes received by the socket.\n* `erlang_vm_dist_recv_cnt`\n  Type: gauge.\n  Number of packets received by the socket.\n* `erlang_vm_dist_recv_max_bytes`\n  Type: gauge.\n  Size of the largest packet, in bytes, received by the socket.\n* `erlang_vm_dist_recv_avg_bytes`\n  Type: gauge.\n  Average size of packets, in bytes, received by the socket.\n* `erlang_vm_dist_recv_dvi_bytes`\n  Type: gauge.\n  Average packet size deviation, in bytes, received by the socket.\n* `erlang_vm_dist_send_bytes`\n  Type: gauge.\n  Number of bytes sent from the socket.\n* `erlang_vm_dist_send_cnt`\n  Type: gauge.\n  Number of packets sent from the socket.\n* `erlang_vm_dist_send_max_bytes`\n  Type: gauge.\n  Size of the largest packet, in bytes, sent from the socket.\n* `erlang_vm_dist_send_avg_bytes`\n  Type: gauge.\n  Average size of packets, in bytes, sent from the socket.\n* `erlang_vm_dist_send_pend_bytes`\n  Type: gauge.\n  Number of bytes waiting to be sent by the socket.\n* `erlang_vm_dist_port_input_bytes`\n  Type: gauge.\n  The total number of bytes read from the port.\n* `erlang_vm_dist_port_output_bytes`\n  Type: gauge.\n  The total number of bytes written to the port.\n* `erlang_vm_dist_port_memory_bytes`\n  Type: gauge.\n  The total number of bytes allocated for this port by the runtime system.\n  The port itself can have allocated memory that is not included.\n* `erlang_vm_dist_port_queue_size_bytes`\n  Type: gauge.\n  The total number of bytes queued by the port using the ERTS driver queue implementation.\n* `erlang_vm_dist_proc_memory_bytes`\n  Type: gauge.\n  The size in bytes of the process. This includes call stack, heap, and internal structures.\n* `erlang_vm_dist_proc_heap_size_words`\n  Type: gauge.\n  The size in words of the youngest heap generation of the process.\n  This generation includes the process stack.\n  This information is highly implementation-dependent, and can change if the implementation changes.\n* `erlang_vm_dist_proc_min_heap_size_words`\n  Type: gauge.\n  The minimum heap size for the process.\n* `erlang_vm_dist_proc_min_bin_vheap_size_words`\n  Type: gauge.\n  The minimum binary virtual heap size for the process.\n* `erlang_vm_dist_proc_stack_size_words`\n  Type: gauge.\n  The stack size, in words, of the process.\n* `erlang_vm_dist_proc_total_heap_size_words`\n  Type: gauge.\n  The total size, in words, of all heap fragments of the process.\n  This includes the process stack and any unreceived messages that are considered\n  to be part of the heap.\n* `erlang_vm_dist_proc_message_queue_len`\n  Type: gauge.\n  The number of messages currently in the message queue of the process.\n* `erlang_vm_dist_proc_reductions`\n  Type: gauge.\n  The number of reductions executed by the process.\n* `erlang_vm_dist_proc_status`\n  Type: gauge.\n  The current status of the distribution process.\n  The status is represented as a numerical value where `exiting=1`, `suspended=2`, `runnable=3`,\n  `garbage_collecting=4`, `running=5` and `waiting=6`.\n* `erlang_vm_dist_node_state`\n  Type: gauge.\n  The current state of the distribution link.\n  The state is represented as a numerical value where `pending=1`, `up_pending=2` and `up=3`.\n* `erlang_vm_dist_node_queue_size_bytes`\n  Type: gauge.\n  The number of bytes in the output distribution queue.\n  This queue sits between the Erlang code and the port driver.","ref":"prometheus_vm_dist_collector.html#module-exported-metrics"},{"type":"module","title":"Configuration - prometheus_vm_dist_collector","doc":"Metrics exported by this collector can be configured via `vm_dist_collector_metrics` key\nof the `prometheus` app environment.\n\nAvailable options:\n\n* `recv_bytes` for `erlang_vm_dist_recv_bytes`.\n* `recv_cnt` for `erlang_vm_dist_recv_cnt`.\n* `recv_max_bytes` for `erlang_vm_dist_recv_max_bytes`.\n* `recv_avg_bytes` for `erlang_vm_dist_recv_avg_bytes`.\n* `recv_dvi_bytes` for `erlang_vm_dist_recv_dvi_bytes`.\n* `send_bytes` for `erlang_vm_dist_send_bytes`.\n* `send_cnt` for `erlang_vm_dist_send_cnt`.\n* `send_max_bytes` for `erlang_vm_dist_send_max_bytes`.\n* `send_avg_bytes` for `erlang_vm_dist_send_avg_bytes`.\n* `send_pend_bytes` for `erlang_vm_dist_send_pend_bytes`.\n* `port_input_bytes` for `erlang_vm_dist_port_input_bytes`.\n* `port_output_bytes` for `erlang_vm_dist_port_output_bytes`.\n* `port_memory_bytes` for `erlang_vm_dist_port_memory_bytes`.\n* `port_queue_size_bytes` for `erlang_vm_dist_port_queue_size_bytes`.\n* `proc_memory_bytes` for `erlang_vm_dist_proc_memory_bytes`.\n* `proc_heap_size_words` for `erlang_vm_dist_proc_heap_size_words`.\n* `proc_min_heap_size_words` for `erlang_vm_dist_proc_min_heap_size_words`.\n* `proc_min_bin_vheap_size_words` for `erlang_vm_dist_proc_min_bin_vheap_size_words`.\n* `proc_stack_size_words` for `erlang_vm_dist_proc_stack_size_words`.\n* `proc_total_heap_size_words` for `erlang_vm_dist_proc_total_heap_size_words`.\n* `proc_message_queue_len` for `erlang_vm_dist_proc_message_queue_len`.\n* `proc_reductions` for `erlang_vm_dist_proc_reductions`.\n* `proc_status` for `erlang_vm_dist_proc_status`.\n* `node_state` for `erlang_vm_dist_node_state`.\n* `node_queue_size_bytes` for `erlang_vm_dist_node_queue_size_bytes`.\n\nBy default all metrics are enabled.","ref":"prometheus_vm_dist_collector.html#module-configuration"},{"type":"module","title":"prometheus_vm_memory_collector","doc":"Collects information about memory dynamically allocated by the Erlang emulator using\n`erlang:memory/0`, also provides basic (D)ETS statistics.","ref":"prometheus_vm_memory_collector.html"},{"type":"module","title":"Exported metrics - prometheus_vm_memory_collector","doc":"* `erlang_vm_memory_atom_bytes_total{usage=\\\"free|used\\\"}`\n  Type: gauge.\n  The total amount of memory currently allocated for atoms.\n    This memory is part of the memory presented as system memory.\n* `erlang_vm_memory_bytes_total{kind=\\\"system|processes\\\"}`\n  Type: gauge.\n  The total amount of memory currently allocated.\n    This is the same as the sum of the memory size for processes and system.\n* `erlang_vm_memory_dets_tables`\n  Type: gauge.\n  Erlang VM DETS Tables count.\n* `erlang_vm_memory_ets_tables`\n  Type: gauge.\n  Erlang VM ETS Tables count.\n* `erlang_vm_memory_processes_bytes_total{usage=\\\"free|used\\\"}`\n  Type: gauge.\n  The total amount of memory currently allocated for the Erlang processes.\n* `erlang_vm_memory_system_bytes_total{usage=\\\"atom|binary|code|ets|other\\\"}`\n  Type: gauge.\n  The total amount of memory currently allocated for the emulator that is not directly related\n    to any Erlang process. Memory presented as processes is not included in this memory.","ref":"prometheus_vm_memory_collector.html#module-exported-metrics"},{"type":"module","title":"Configuration - prometheus_vm_memory_collector","doc":"Metrics exported by this collector can be configured via `vm_memory_collector_metrics` key\nof the `prometheus` app environment.\n\nAvailable options:\n\n* `atom_bytes_total` for `erlang_vm_memory_atom_bytes_total`.\n* `bytes_total` for `erlang_vm_memory_bytes_total`.\n* `dets_tables` for `erlang_vm_dets_tables`.\n* `ets_tables` for `erlang_vm_ets_tables`.\n* `processes_bytes_total` for `erlang_vm_memory_processes_bytes_total`.\n* `system_bytes_total` for `erlang_vm_memory_system_bytes_total`.\n\nBy default all metrics are enabled.","ref":"prometheus_vm_memory_collector.html#module-configuration"},{"type":"module","title":"prometheus_vm_msacc_collector","doc":"Collects microstate accounting metrics using\n[`erlang:statistics(microstate_accounting)`]\n(http://erlang.org/doc/man/erlang.html#statistics_microstate_accounting).\n\nIn order for values to increase, microstate accounting must be enabled.\nThis is done by calling `erlang:system_flag(microstate_accounting, true).`","ref":"prometheus_vm_msacc_collector.html"},{"type":"module","title":"Exported metrics - prometheus_vm_msacc_collector","doc":"Some metrics are not available by default.\nThey require a VM configured with `./configure --with-microstate-accounting=extra`.\n\n* `erlang_vm_msacc_aux_seconds_total`\n  Type: counter.\n  Total time in seconds spent handling auxiliary jobs.\n* `erlang_vm_msacc_check_io_seconds_total`\n  Type: counter.\n  Total time in seconds spent checking for new I/O events.\n* `erlang_vm_msacc_emulator_seconds_total`\n  Type: counter.\n  Total time in seconds spent executing Erlang processes.\n* `erlang_vm_msacc_gc_seconds_total`\n  Type: counter.\n  Total time in seconds spent doing garbage collection.\n    When extra states are enabled this is the time spent doing non-fullsweep garbage collections.\n* `erlang_vm_msacc_other_seconds_total`\n  Type: counter.\n  Total time in seconds spent doing unaccounted things.\n* `erlang_vm_msacc_port_seconds_total`\n  Type: counter.\n  Total time in seconds spent executing ports.\n* `erlang_vm_msacc_sleep_seconds_total`\n  Type: counter.\n  Total time in seconds spent sleeping.\n* `erlang_vm_msacc_alloc_seconds_total`\n  Type: counter.\n  Total time in seconds spent managing memory.\n    Without extra states this time is spread out over all other states.\n* `erlang_vm_msacc_bif_seconds_total`\n  Type: counter.\n  Total time in seconds spent in BIFs.\n    Without extra states this time is part of the 'emulator' state.\n* `erlang_vm_msacc_busy_wait_seconds_total`\n  Type: counter.\n  Total time in seconds spent busy waiting.\n    Without extra states this time is part of the 'other' state.\n* `erlang_vm_msacc_ets_seconds_total`\n  Type: counter.\n  Total time in seconds spent executing ETS BIFs.\n    Without extra states this time is part of the 'emulator' state.\n* `erlang_vm_msacc_gc_full_seconds_total`\n  Type: counter.\n  Total time in seconds spent doing fullsweep garbage collection.\n    Without extra states this time is part of the 'gc' state.\n* `erlang_vm_msacc_nif_seconds_total`\n  Type: counter.\n  Total time in seconds spent in NIFs.\n    Without extra states this time is part of the 'emulator' state.\n* `erlang_vm_msacc_send_seconds_total`\n  Type: counter.\n  Total time in seconds spent sending messages (processes only).\n    Without extra states this time is part of the 'emulator' state.\n* `erlang_vm_msacc_timers_seconds_total`\n  Type: counter.\n  Total time in seconds spent managing timers.\n    Without extra states this time is part of the 'other' state.","ref":"prometheus_vm_msacc_collector.html#module-exported-metrics"},{"type":"module","title":"Configuration - prometheus_vm_msacc_collector","doc":"Metrics exported by this collector can be configured via `vm_msacc_collector_metrics` key\nof the `prometheus` app environment.\n\nOptions are the same as MSAcc_Thread_State return type from\n[`erlang:statistics(microstate_accounting)`]\n(http://erlang.org/doc/man/erlang.html#statistics_microstate_accounting)\nwith `_seconds_total` as the suffix:\n\n* `aux_seconds_total` for `erlang_vm_msacc_aux_seconds_total`.\n* `check_io_seconds_total` for `erlang_vm_msacc_check_io_seconds_total`.\n* `emulator_seconds_total` for `erlang_vm_msacc_emulator_seconds_total`.\n* `gc_seconds_total` for `erlang_vm_msacc_gc_seconds_total`.\n* `other_seconds_total` for `erlang_vm_msacc_other_seconds_total`.\n* `port_seconds_total` for `erlang_vm_msacc_port_seconds_total`.\n* `sleep_seconds_total` for `erlang_vm_msacc_sleep_seconds_total`.\n* `alloc_seconds_total` for `erlang_vm_msacc_alloc_seconds_total`.\n* `bif_seconds_total` for `erlang_vm_msacc_bif_seconds_total`.\n* `busy_wait_seconds_total` for `erlang_vm_msacc_busy_wait_seconds_total`.\n* `ets_seconds_total` for `erlang_vm_msacc_ets_seconds_total`.\n* `gc_full_seconds_total` for `erlang_vm_msacc_gc_full_seconds_total`.\n* `nif_seconds_total` for `erlang_vm_msacc_nif_seconds_total`.\n* `send_seconds_total` for `erlang_vm_msacc_send_seconds_total`.\n* `timers_seconds_total` for `erlang_vm_msacc_timers_seconds_total`.\n\nBy default all metrics are enabled as far as Prometheus is concerned,\nalthough some metrics could not be enabled by the VM itself.","ref":"prometheus_vm_msacc_collector.html#module-configuration"},{"type":"module","title":"prometheus_vm_statistics_collector","doc":"Collects Erlang VM metrics using `erlang:statistics/1`.","ref":"prometheus_vm_statistics_collector.html"},{"type":"module","title":"Exported metrics - prometheus_vm_statistics_collector","doc":"* `erlang_vm_statistics_bytes_output_total`\n  Type: counter.\n  The total number of bytes output to ports.\n* `erlang_vm_statistics_bytes_received_total`\n  Type: counter.\n  The total number of bytes received through ports.\n* `erlang_vm_statistics_context_switches`\n  Type: counter.\n  The total number of context switches since the system started.\n* `erlang_vm_statistics_dirty_cpu_run_queue_length`\n  Type: gauge.\n  Length of the dirty CPU run-queue.\n* `erlang_vm_statistics_dirty_io_run_queue_length`\n  Type: gauge.\n  Length of the dirty IO run-queue.\n* `erlang_vm_statistics_garbage_collection_number_of_gcs`\n  Type: counter.\n  The total number of garbage collections since the system started.\n* `erlang_vm_statistics_garbage_collection_words_reclaimed`\n  Type: counter.\n  The total number of words reclaimed by GC since the system started.\n* `erlang_vm_statistics_garbage_collection_bytes_reclaimed`\n  Type: counter.\n  The total number of bytes reclaimed by GC since the system started.\n* `erlang_vm_statistics_reductions_total`\n  Type: counter.\n  Total reductions count.\n* `erlang_vm_statistics_run_queues_length`\n  Type: gauge.\n  The total length of all normal run-queues. That is, the number of processes and ports that\n    are ready to run on all available normal run-queues.\n* `erlang_vm_statistics_runtime_milliseconds`\n  Type: counter.\n  The sum of the runtime for all threads in the Erlang runtime system.\n* `erlang_vm_statistics_wallclock_time_milliseconds`\n  Type: counter.\n  Can be used in the same manner as `erlang_vm_statistics_runtime_milliseconds`,\n    except that real time is measured as opposed to runtime or CPU time.","ref":"prometheus_vm_statistics_collector.html#module-exported-metrics"},{"type":"module","title":"Configuration - prometheus_vm_statistics_collector","doc":"Metrics exported by this collector can be configured via `vm_statistics_collector_metrics` key\nof the `prometheus` app environment.\n\nOptions are the same as the `Item` parameter values for `erlang:statistics/1`:\n\n* `context_switches` for `erlang_vm_statistics_context_switches`;\n* `garbage_collection` for `erlang_vm_statistics_garbage_collection_number_of_gcs`,\n    `erlang_vm_statistics_garbage_collection_bytes_reclaimed`,\n    and `erlang_vm_statistics_garbage_collection_words_reclaimed`;\n* `io` for `erlang_vm_statistics_bytes_output_total` and `erlang_vm_statistics_bytes_received_total`;\n* `reductions` for `erlang_vm_statistics_reductions_total`;\n* `run_queue` for `erlang_vm_statistics_run_queues_length`;\n* `runtime` for `erlang_vm_statistics_runtime_milliseconds`;\n* `wall_clock` for `erlang_vm_statistics_wallclock_time_milliseconds`.\n\nBy default all metrics are enabled.","ref":"prometheus_vm_statistics_collector.html#module-configuration"},{"type":"module","title":"prometheus_vm_system_info_collector","doc":"Collects Erlang VM metrics using `erlang:system_info/1`.","ref":"prometheus_vm_system_info_collector.html"},{"type":"module","title":"Exported metrics - prometheus_vm_system_info_collector","doc":"* `erlang_vm_dirty_cpu_schedulers`\n  Type: gauge.\n  The number of scheduler dirty CPU scheduler threads used by the emulator.\n* `erlang_vm_dirty_cpu_schedulers_online`\n  Type: gauge.\n  The number of dirty CPU scheduler threads online.\n* `erlang_vm_dirty_io_schedulers`\n  Type: gauge.\n  The number of scheduler dirty I/O scheduler threads used by the emulator.\n* `erlang_vm_ets_limit`\n  Type: gauge.\n  The maximum number of ETS tables allowed.\n* `erlang_vm_logical_processors`\n  Type: gauge.\n  The detected number of logical processors configured in the system.\n* `erlang_vm_logical_processors_available`\n  Type: gauge.\n  The detected number of logical processors available to the Erlang runtime system.\n* `erlang_vm_logical_processors_online`\n  Type: gauge.\n  The detected number of logical processors online on the system.\n* `erlang_vm_port_count`\n  Type: gauge.\n  The number of ports currently existing at the local node.\n* `erlang_vm_port_limit`\n  Type: gauge.\n  The maximum number of simultaneously existing ports at the local node.\n* `erlang_vm_process_count`\n  Type: gauge.\n  The number of processes currently existing at the local node.\n* `erlang_vm_process_limit`\n  Type: gauge.\n  The maximum number of simultaneously existing processes at the local node.\n* `erlang_vm_schedulers`\n  Type: gauge.\n  The number of scheduler threads used by the emulator.\n* `erlang_vm_schedulers_online`\n  Type: gauge.\n  The number of schedulers online.\n* `erlang_vm_smp_support`\n  Type: boolean.\n  1 if the emulator has been compiled with SMP support, otherwise 0.\n* `erlang_vm_threads`\n  Type: boolean.\n  1 if the emulator has been compiled with thread support, otherwise 0.\n* `erlang_vm_thread_pool_size`\n  Type: gauge.\n  The number of async threads in the async thread pool used for asynchronous driver calls.\n* `erlang_vm_time_correction`\n  Type: boolean.\n  1 if time correction is enabled, otherwise 0.\n* `erlang_vm_wordsize_bytes`\n  Type: gauge.\n  The size of Erlang term words in bytes.\n* `erlang_vm_atom_count`\n  Type: gauge.\n  The number of atom currently existing at the local node.\n* `erlang_vm_atom_limit`\n  Type: gauge.\n  The maximum number of simultaneously existing atom at the local node.\n* `erlang_vm_allocators`\n  Type: gauge.\n  Allocated (carriers_size) and used (blocks_size) memory for the different allocators in the VM.\n    See erts_alloc(3).","ref":"prometheus_vm_system_info_collector.html#module-exported-metrics"},{"type":"module","title":"Configuration - prometheus_vm_system_info_collector","doc":"Metrics exported by this collector can be configured via `vm_system_info_collector_metrics` key\nof the `prometheus` app environment.\n\nOptions are the same as Item parameter values for `erlang:system_info/1`:\n\n* `ets_limit` for `erlang_vm_ets_limit`.\n* `logical_processors` for `erlang_vm_logical_processors`.\n* `logical_processors_available` for `erlang_vm_logical_processors_available`.\n* `logical_processors_online` for `erlang_vm_logical_processors_online`.\n* `port_count` for `erlang_vm_port_count`.\n* `port_limit` for `erlang_vm_port_limit`.\n* `process_count` for `erlang_vm_process_count`.\n* `process_limit` for `erlang_vm_process_limit`.\n* `schedulers` for `erlang_vm_schedulers`.\n* `schedulers_online` for `erlang_vm_schedulers_online`.\n* `smp_support` for `erlang_vm_smp_support`.\n* `threads` for `erlang_threads`.\n* `thread_pool_size` for `erlang_vm_thread_pool_size`.\n* `time_correction` for `erlang_vm_time_correction`.\n* `wordsize_bytes` for `erlang_vm_wordsize_bytes`.\n* `atom_count` for `erlang_vm_atom_count`.\n* `atom_limit` for `erlang_vm_atom_limit`.\n* `allocators` for `erlang_vm_allocators`.\n\nBy default all metrics are enabled.","ref":"prometheus_vm_system_info_collector.html#module-configuration"},{"type":"module","title":"prometheus_http","doc":"HTTP instrumentation helpers","ref":"prometheus_http.html"},{"type":"function","title":"prometheus_http.microseconds_duration_buckets/0","doc":"Returns default microseconds buckets for measuring http requests duration.\n\n```erlang\n1> prometheus_http:microseconds_duration_buckets().\n[10, 25, 50, 100, 250, 500,\n 1000, 2500, 5000, 10000, 25000, 50000, 100000, 250000, 500000,\n 1000000, 2500000, 5000000, 10000000]\n```","ref":"prometheus_http.html#microseconds_duration_buckets/0"},{"type":"function","title":"prometheus_http.status_class/1","doc":"Returns status class for the http status code `SCode`.\n\n```erlang\n2> prometheus_http:status_class(202).\n\\\"success\\\"\n\n```\n\nRaises `{invalid_value_error, SCode, Message}` error if `SCode` isn't a positive integer.","ref":"prometheus_http.html#status_class/1"},{"type":"type","title":"prometheus_http.status_class/0","doc":"","ref":"prometheus_http.html#t:status_class/0"},{"type":"type","title":"prometheus_http.status_code/0","doc":"","ref":"prometheus_http.html#t:status_code/0"},{"type":"module","title":"prometheus_mnesia","doc":"Mnesia instrumentation helpers.","ref":"prometheus_mnesia.html"},{"type":"function","title":"prometheus_mnesia.table_disk_size/1","doc":"","ref":"prometheus_mnesia.html#table_disk_size/1"},{"type":"function","title":"prometheus_mnesia.table_disk_size/2","doc":"Returns sum of all mnesia files for the given `Table` in bytes.\nMnesia can create different files for each table:\n- .DAT: DETS files\n- .TMP: temp files\n- .DMP: dumped ets tables\n- .DCD: disc copies data\n- .DCL: disc copies log\n- .LOGTMP: disc copies log\n\nMore on Mnesia files can be found in\n[Mnesia System Information chapter](http://erlang.org/doc/apps/mnesia/Mnesia_chap7.html)\nof Mnesia User's Guide.","ref":"prometheus_mnesia.html#table_disk_size/2"},{"type":"function","title":"prometheus_mnesia.tm_info/0","doc":"Returns `{PCount, CCount}` tuple, where `PCount` is a number of participant transactions\nand `CCount` is a number of coordinator transactions.\n\nCan return `{undefined, undefined}` occasionally.","ref":"prometheus_mnesia.html#tm_info/0"},{"type":"module","title":"prometheus_boolean","doc":"Boolean metric, to report booleans and flags.\n\nBoolean is a non-standard metric that uses untyped metric underneath.\n\nA Boolean is typically used as a flag i.e. enabled/disabled, online/offline.\n\nExample:\n\n```erlang\n-module(my_fuse_instrumenter).\n\n-export([setup/0, fuse_event/2]).\n\nsetup() ->\n    prometheus_boolean:declare([{name, app_fuse_state},\n                                {labels, [name]}, %% fuse name\n                                {help, \\\"State of various app fuses.\\\"}]),\n\nfuse_event(Fuse, Event) ->\n    case Event of\n        ok -> prometheus_boolean:set(app_fuse_state, [Fuse], true);\n        blown -> prometheus_boolean:set(app_fuse_state, [Fuse], false);\n        _ -> ok\n    end.\n```","ref":"prometheus_boolean.html"},{"type":"function","title":"prometheus_boolean.declare/1","doc":"Creates a boolean using `Spec`.\n\nIf a boolean with the same `Spec` exists returns `false`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.","ref":"prometheus_boolean.html#declare/1"},{"type":"function","title":"prometheus_boolean.deregister/1","doc":"","ref":"prometheus_boolean.html#deregister/1"},{"type":"function","title":"prometheus_boolean.deregister/2","doc":"Removes all boolean series with name `Name` and removes Metric Family from `Registry`.\n\nAfter this call new/1 for `Name` and `Registry` will succeed.\n\nReturns `{true, _}` if `Name` was a registered boolean. Otherwise returns `{true, _}`.","ref":"prometheus_boolean.html#deregister/2"},{"type":"function","title":"prometheus_boolean.new/1","doc":"Creates a boolean using `Spec`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{mf_already_exists, {Registry, Name}, Message}` error if a boolean with the same `Spec` already exists.","ref":"prometheus_boolean.html#new/1"},{"type":"function","title":"prometheus_boolean.remove/1","doc":"","ref":"prometheus_boolean.html#remove/1"},{"type":"function","title":"prometheus_boolean.remove/2","doc":"","ref":"prometheus_boolean.html#remove/2"},{"type":"function","title":"prometheus_boolean.remove/3","doc":"Removes boolean series identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if boolean with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_boolean.html#remove/3"},{"type":"function","title":"prometheus_boolean.reset/1","doc":"","ref":"prometheus_boolean.html#reset/1"},{"type":"function","title":"prometheus_boolean.reset/2","doc":"","ref":"prometheus_boolean.html#reset/2"},{"type":"function","title":"prometheus_boolean.reset/3","doc":"Resets the value of the boolean identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if boolean with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_boolean.html#reset/3"},{"type":"function","title":"prometheus_boolean.set/2","doc":"","ref":"prometheus_boolean.html#set/2"},{"type":"function","title":"prometheus_boolean.set/3","doc":"","ref":"prometheus_boolean.html#set/3"},{"type":"function","title":"prometheus_boolean.set/4","doc":"Sets the boolean identified by `Registry`, `Name` and `LabelValues` to `Value`.\n\nValid truthy values:\n\n* `true`;\n* `false`;\n* `0` -> false;\n* `number > 0` -> true;\n* `[]` -> false;\n* `non-empty list` -> true;\n* `undefined` -> undefined;\n\nOther values will generate `invalid_value` error.\n\nRaises:\n\n* `{invalid_value, Value, Message}` if `Value` isn't a boolean or `undefined`.\n* `{unknown_metric, Registry, Name}` error if boolean with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_boolean.html#set/4"},{"type":"function","title":"prometheus_boolean.toggle/1","doc":"","ref":"prometheus_boolean.html#toggle/1"},{"type":"function","title":"prometheus_boolean.toggle/2","doc":"","ref":"prometheus_boolean.html#toggle/2"},{"type":"function","title":"prometheus_boolean.toggle/3","doc":"Toggles the boolean identified by `Registry`, `Name` and `LabelValues`.\n\nIf boolean set to undefined, it can't be toggled.\n\nRaises:\n\n* `{invalid_value, undefined, Message}` if boolean is undefined.\n* `{unknown_metric, Registry, Name}` error if boolean with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_boolean.html#toggle/3"},{"type":"function","title":"prometheus_boolean.value/1","doc":"","ref":"prometheus_boolean.html#value/1"},{"type":"function","title":"prometheus_boolean.value/2","doc":"","ref":"prometheus_boolean.html#value/2"},{"type":"function","title":"prometheus_boolean.value/3","doc":"Returns the value of the boolean identified by `Registry`, `Name` and `LabelValues`.\nIf there is no boolean for `LabelValues`, returns `undefined`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if boolean named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_boolean.html#value/3"},{"type":"function","title":"prometheus_boolean.values/2","doc":"","ref":"prometheus_boolean.html#values/2"},{"type":"module","title":"prometheus_counter","doc":"Counter is a Metric that represents a single numerical value that only ever goes up.\nThat implies that it cannot be used to count items whose number can also go down, e. g.\nthe number of currently running processes. Those \\\"counters\\\" are represented by `m:prometheus_gauge`.\n\nA Counter is typically used to count requests served, tasks completed, errors occurred, etc.\n\nExamople use cases for Counters:\n\n* Number of requests processed\n* Number of items that were inserted into a queue\n* Total amount of data a system has processed\n\nUse the [rate()](https://prometheus.io/docs/querying/functions/#rate())/\n[irate()](https://prometheus.io/docs/querying/functions/#irate())\nfunctions in Prometheus to calculate the rate of increase of a Counter.\nBy convention, the names of Counters are suffixed by `_total`.\n\nTo create a counter use either `new/1` or `declare/1`, the difference is that `new/1` will raise\n`{mf_already_exists, {Registry, Name}, Message}` error if counter with the same\n`Registry`, `Name` and `Labels` combination already exists.\nBoth accept `Spec` `t:proplists:proplist/0` with the same set of keys:\n\n* `Registry`: optional, default is `default`;\n* `Name`: required, can be an atom or a string;\n* `Help`: required, must be a string;\n* `Labels`: optional, default is `[]`.\n\nExample:\n\n```erlang\n-module(my_service_instrumenter).\n\n-export([setup/0, inc/1]).\n\nsetup() ->\n    prometheus_counter:declare([{name, my_service_requests_total},\n                                {help, \\\"Requests count\\\"},\n                                {labels, caller}]).\n\ninc(Caller) ->\n    prometheus_counter:inc(my_service_requests_total, [Caller]).\n```","ref":"prometheus_counter.html"},{"type":"function","title":"prometheus_counter.declare/1","doc":"Creates a counter using `Spec`, if a counter with the same `Spec` exists returns `false`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.","ref":"prometheus_counter.html#declare/1"},{"type":"function","title":"prometheus_counter.deregister/1","doc":"","ref":"prometheus_counter.html#deregister/1"},{"type":"function","title":"prometheus_counter.deregister/2","doc":"Removes all counter series with name `Name` and removes Metric Family from `Registry`.\n\nAfter this call new/1 for `Name` and `Registry` will succeed.\n\nReturns `{true, _}` if `Name` was a registered counter. Otherwise returns `{true, _}`.","ref":"prometheus_counter.html#deregister/2"},{"type":"function","title":"prometheus_counter.inc/1","doc":"","ref":"prometheus_counter.html#inc/1"},{"type":"function","title":"prometheus_counter.inc/2","doc":"If the second argument is a list, equivalent to [inc(default, Name, LabelValues,\n1)](`inc/4`) otherwise equivalent to [inc(default, Name, [], Value)](`inc/4`).","ref":"prometheus_counter.html#inc/2"},{"type":"function","title":"prometheus_counter.inc/3","doc":"","ref":"prometheus_counter.html#inc/3"},{"type":"function","title":"prometheus_counter.inc/4","doc":"Increments the counter identified by `Registry`, `Name` and `LabelValues` by `Value`.\n\nRaises:\n\n* `{invalid_value, Value, Message}` if `Value` isn't a positive number.\n* `{unknown_metric, Registry, Name}` error if counter with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_counter.html#inc/4"},{"type":"function","title":"prometheus_counter.new/1","doc":"Creates a counter using `Spec`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{mf_already_exists, {Registry, Name}, Message}` error if a counter with the same `Spec` already exists.","ref":"prometheus_counter.html#new/1"},{"type":"function","title":"prometheus_counter.remove/1","doc":"Equivalent to [remove(default, Name, [])](`remove/3`).","ref":"prometheus_counter.html#remove/1"},{"type":"function","title":"prometheus_counter.remove/2","doc":"Equivalent to [remove(default, Name, LabelValues)](`remove/3`).","ref":"prometheus_counter.html#remove/2"},{"type":"function","title":"prometheus_counter.remove/3","doc":"Removes counter series identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if counter with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_counter.html#remove/3"},{"type":"function","title":"prometheus_counter.reset/1","doc":"","ref":"prometheus_counter.html#reset/1"},{"type":"function","title":"prometheus_counter.reset/2","doc":"","ref":"prometheus_counter.html#reset/2"},{"type":"function","title":"prometheus_counter.reset/3","doc":"Resets the value of the counter identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if counter with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_counter.html#reset/3"},{"type":"function","title":"prometheus_counter.value/1","doc":"","ref":"prometheus_counter.html#value/1"},{"type":"function","title":"prometheus_counter.value/2","doc":"","ref":"prometheus_counter.html#value/2"},{"type":"function","title":"prometheus_counter.value/3","doc":"Returns the value of the counter identified by `Registry`, `Name` and `LabelValues`.\n\nIf there is no counter for `LabelValues`, returns `undefined`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if counter named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_counter.html#value/3"},{"type":"function","title":"prometheus_counter.values/2","doc":"","ref":"prometheus_counter.html#values/2"},{"type":"module","title":"prometheus_gauge","doc":"Gauge metric, to report instantaneous values.\n\nGauge is a metric that represents a single numerical value that can arbitrarily go up and down.\n\nA Gauge is typically used for measured values like temperatures or current memory usage,\nbut also \\\"counts\\\" that can go up and down, like the number of running processes.\n\nIt can take the value of undefined when the value is not known.\nIn that case, increments and decrements will not be possible\nand explicitly setting to a new value will be necessary.\n\nExample use cases for Gauges:\n\n* In-progress requests\n* Number of items in a queue\n* Free memory\n* Total memory\n* Temperature\n\nExample:\n\n```erlang\n-module(my_pool_instrumenter).\n\n-export([setup/0, set_size/1]).\n\nsetup() ->\n    prometheus_gauge:declare([{name, my_pool_size},\n                              {help, \\\"Pool size.\\\"}]),\n    prometheus_gauge:declare([{name, my_pool_checked_out},\n                              {help, \\\"Number of checked out sockets\\\"}]).\n\nset_size(Size) ->\n    prometheus_gauge:set(my_pool_size, Size)\n\ntrack_checked_out_sockets(CheckoutFun) ->\n    prometheus_gauge:track_inprogress(my_pool_checked_out, CheckoutFun)..\n```","ref":"prometheus_gauge.html"},{"type":"function","title":"prometheus_gauge.dec/1","doc":"","ref":"prometheus_gauge.html#dec/1"},{"type":"function","title":"prometheus_gauge.dec/2","doc":"If the second argument is a list, equivalent to [inc(default, Name, LabelValues, -1)](`inc/4`)\notherwise equivalent to [inc(default, Name, [], -Value)](`inc/4`).","ref":"prometheus_gauge.html#dec/2"},{"type":"function","title":"prometheus_gauge.dec/3","doc":"","ref":"prometheus_gauge.html#dec/3"},{"type":"function","title":"prometheus_gauge.dec/4","doc":"","ref":"prometheus_gauge.html#dec/4"},{"type":"function","title":"prometheus_gauge.declare/1","doc":"Creates a gauge using `Spec`. If a gauge with the same `Spec` exists returns `false`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, MessagE}` error if `duration_unit` is unknown or doesn't match metric name.","ref":"prometheus_gauge.html#declare/1"},{"type":"function","title":"prometheus_gauge.deregister/1","doc":"","ref":"prometheus_gauge.html#deregister/1"},{"type":"function","title":"prometheus_gauge.deregister/2","doc":"Removes all gauge series with name `Name` and removes Metric Family from `Registry`.\n\nAfter this call new/1 for `Name` and `Registry` will succeed.\n\nReturns `{true, _}` if `Name` was a registered gauge. Otherwise returns `{false, _}`.","ref":"prometheus_gauge.html#deregister/2"},{"type":"function","title":"prometheus_gauge.inc/1","doc":"","ref":"prometheus_gauge.html#inc/1"},{"type":"function","title":"prometheus_gauge.inc/2","doc":"If the second argument is a list, equivalent to [inc(default, Name, LabelValues, 1)](`inc/4`)\notherwise equivalent to [inc(default, Name, [], Value)](`inc/4`).","ref":"prometheus_gauge.html#inc/2"},{"type":"function","title":"prometheus_gauge.inc/3","doc":"","ref":"prometheus_gauge.html#inc/3"},{"type":"function","title":"prometheus_gauge.inc/4","doc":"Increments the gauge identified by `Registry`, `Name` and `LabelValues` by `Value`.\n\nRaises:\n\n* `{invalid_value, Value, Message}` if `Value` isn't an integer.\n* `{unknown_metric, Registry, Name}` error if gauge with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_gauge.html#inc/4"},{"type":"function","title":"prometheus_gauge.new/1","doc":"Creates a gauge using `Spec`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, Message}` error if `duration_unit` is unknown or doesn't match metric name.\n* `{mf_already_exists, {Registry, Name}, Message}` error if a gauge with the same `Spec` already exists.","ref":"prometheus_gauge.html#new/1"},{"type":"function","title":"prometheus_gauge.remove/1","doc":"","ref":"prometheus_gauge.html#remove/1"},{"type":"function","title":"prometheus_gauge.remove/2","doc":"","ref":"prometheus_gauge.html#remove/2"},{"type":"function","title":"prometheus_gauge.remove/3","doc":"Removes gauge series identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if gauge with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_gauge.html#remove/3"},{"type":"function","title":"prometheus_gauge.reset/1","doc":"","ref":"prometheus_gauge.html#reset/1"},{"type":"function","title":"prometheus_gauge.reset/2","doc":"","ref":"prometheus_gauge.html#reset/2"},{"type":"function","title":"prometheus_gauge.reset/3","doc":"Resets the value of the gauge identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if gauge with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_gauge.html#reset/3"},{"type":"function","title":"prometheus_gauge.set/2","doc":"","ref":"prometheus_gauge.html#set/2"},{"type":"function","title":"prometheus_gauge.set/3","doc":"","ref":"prometheus_gauge.html#set/3"},{"type":"function","title":"prometheus_gauge.set/4","doc":"Sets the gauge identified by `Registry`, `Name` and `LabelValues` to `Value`.\n\nRaises:\n\n* `{invalid_value, Value, Message}` if `Value` isn't a number or `undefined`.\n* `{unknown_metric, Registry, Name}` error if gauge with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_gauge.html#set/4"},{"type":"function","title":"prometheus_gauge.set_duration/2","doc":"","ref":"prometheus_gauge.html#set_duration/2"},{"type":"function","title":"prometheus_gauge.set_duration/3","doc":"","ref":"prometheus_gauge.html#set_duration/3"},{"type":"function","title":"prometheus_gauge.set_duration/4","doc":"Sets the gauge identified by `Registry`, `Name` and `LabelValues` to the the amount of time\nspent executing `Fun`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if gauge with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.\n* `{invalid_value, Value, Message}` if `Fun` isn't a function.","ref":"prometheus_gauge.html#set_duration/4"},{"type":"function","title":"prometheus_gauge.set_to_current_time/1","doc":"","ref":"prometheus_gauge.html#set_to_current_time/1"},{"type":"function","title":"prometheus_gauge.set_to_current_time/2","doc":"","ref":"prometheus_gauge.html#set_to_current_time/2"},{"type":"function","title":"prometheus_gauge.set_to_current_time/3","doc":"Sets the gauge identified by `Registry`, `Name` and `LabelValues` to the current unixtime.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if gauge with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_gauge.html#set_to_current_time/3"},{"type":"function","title":"prometheus_gauge.track_inprogress/2","doc":"","ref":"prometheus_gauge.html#track_inprogress/2"},{"type":"function","title":"prometheus_gauge.track_inprogress/3","doc":"","ref":"prometheus_gauge.html#track_inprogress/3"},{"type":"function","title":"prometheus_gauge.track_inprogress/4","doc":"Sets the gauge identified by `Registry`, `Name` and `LabelValues` to the number of\ncurrently executing `Fun`s.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if gauge with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.\n* `{invalid_value, Value, Message}` if `Fun` isn't a function.","ref":"prometheus_gauge.html#track_inprogress/4"},{"type":"function","title":"prometheus_gauge.value/1","doc":"","ref":"prometheus_gauge.html#value/1"},{"type":"function","title":"prometheus_gauge.value/2","doc":"","ref":"prometheus_gauge.html#value/2"},{"type":"function","title":"prometheus_gauge.value/3","doc":"Returns the value of the gauge identified by `Registry`, `Name` and `LabelValues`.\nIf there is no gauge for `LabelValues`, returns `undefined`.\n\nIf duration unit set, value will be converted to the duration unit.\n[Read more here.](`m:prometheus_time`)\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if gauge named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_gauge.html#value/3"},{"type":"function","title":"prometheus_gauge.values/2","doc":"","ref":"prometheus_gauge.html#values/2"},{"type":"module","title":"prometheus_histogram","doc":"A Histogram tracks the size and number of events in buckets.\nYou can use Histograms for aggregatable calculation of quantiles.\n\nExample use cases for Histograms:\n\n* Response latency\n* Request size\n\nHistogram expects `buckets` key in a metric spec. Buckets can be:\n\n* a list of numbers in increasing order;\n* `default`;\n* `{linear, Start, Step, Count`;\n* `{exponential, Start, Step, Count}`\n\nExample:\n\n```erlang\n-module(example_instrumenter).\n\nsetup() ->\n    prometheus_histogram:declare([{name, http_request_duration_milliseconds},\n                                  {labels, [method]},\n                                  {buckets, [100, 300, 500, 750, 1000]},\n                                  {help, \\\"Http Request execution time.\\\"}]).\n\ninstrument(Time, Method) ->\n    %% Time must be in native units, otherwise duration_unit must be false\n    prometheus_histogram:observe(http_request_duration_milliseconds, [Method], Time).\n```\n\nThe `prometheus_histogram:observe_n/3,4,5` adds limited support for the \\\"weighted\\\" histograms.\nIt accepts the extra integer argument \\\"Count\\\" to update the number of observations in the bucket\nby adding that number. This allows for better accuracy in the case of irregular measurements,\nassuming that the \\\"Count\\\" conveys the observation time interval (for example,\nthe number of time ticks when the recent value was observed).","ref":"prometheus_histogram.html"},{"type":"function","title":"prometheus_histogram.buckets/1","doc":"","ref":"prometheus_histogram.html#buckets/1"},{"type":"function","title":"prometheus_histogram.buckets/2","doc":"","ref":"prometheus_histogram.html#buckets/2"},{"type":"function","title":"prometheus_histogram.buckets/3","doc":"Returns buckets of the histogram identified by `Registry`, `Name` and `LabelValues`.","ref":"prometheus_histogram.html#buckets/3"},{"type":"function","title":"prometheus_histogram.declare/1","doc":"Creates a histogram using `Spec`. If a histogram with the same `Spec` exists returns `false`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, MessagE}` error if `duration_unit` is unknown or doesn't match metric name.\n\nHistogram-specific errors:\n\nRaises:\n\n* `{no_buckets, Buckets}` error if `Buckets` are missing, not a list, empty list or not known buckets spec.\n* `{invalid_buckets, Buckets, Message}` error if `Buckets` aren't in increasing order.\n* `{invalid_bound, Bound}` error if `Bound` isn't a number.","ref":"prometheus_histogram.html#declare/1"},{"type":"function","title":"prometheus_histogram.deregister/1","doc":"","ref":"prometheus_histogram.html#deregister/1"},{"type":"function","title":"prometheus_histogram.deregister/2","doc":"Removes all histogram series with name `Name` and removes Metric Family from `Registry`.\n\nAfter this call new/1 for `Name` and `Registry` will succeed.\n\nReturns `{true, _}` if `Name` was a registered histogram. Otherwise returns `{false, _}`.","ref":"prometheus_histogram.html#deregister/2"},{"type":"function","title":"prometheus_histogram.new/1","doc":"Creates a histogram using `Spec`.\n\nRaises:\n\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, Message}` error if `duration_unit` is unknown or doesn't match metric name.\n* `{mf_already_exists, {Registry, Name}, Message}` error if a histogram with the same `Spec` already exists.\n\nHistogram-specific errors:\n\nRaises:\n\n* `{no_buckets, Buckets}` error if `Buckets` are missing, not a list, empty list or not known buckets spec.\n* `{invalid_buckets, Buckets, Message}` error if `Buckets` aren't in increasing order.\n* `{invalid_bound, Bound}` error if `Bound` isn't a number.","ref":"prometheus_histogram.html#new/1"},{"type":"function","title":"prometheus_histogram.observe/2","doc":"","ref":"prometheus_histogram.html#observe/2"},{"type":"function","title":"prometheus_histogram.observe/3","doc":"","ref":"prometheus_histogram.html#observe/3"},{"type":"function","title":"prometheus_histogram.observe/4","doc":"Observes the given `Value`.\n\nRaises:\n\n* `{invalid_value, Value, Message}` if `Value` isn't a number.\n* `{unknown_metric, Registry, Name}` error if histogram with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_histogram.html#observe/4"},{"type":"function","title":"prometheus_histogram.observe_duration/2","doc":"","ref":"prometheus_histogram.html#observe_duration/2"},{"type":"function","title":"prometheus_histogram.observe_duration/3","doc":"","ref":"prometheus_histogram.html#observe_duration/3"},{"type":"function","title":"prometheus_histogram.observe_duration/4","doc":"Tracks the amount of time spent executing `Fun`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if histogram with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.\n* `{invalid_value, Value, Message}` if `Fun` isn't a function.","ref":"prometheus_histogram.html#observe_duration/4"},{"type":"function","title":"prometheus_histogram.observe_n/3","doc":"","ref":"prometheus_histogram.html#observe_n/3"},{"type":"function","title":"prometheus_histogram.observe_n/4","doc":"","ref":"prometheus_histogram.html#observe_n/4"},{"type":"function","title":"prometheus_histogram.observe_n/5","doc":"Observes the given `Value`, `Count` times.\n\nRaises:\n\n* `{invalid_value, Value, Message}` if `Value` isn't a number.\n* `{invalid_count, Count, Message}` if `Count` isn't integer.\n* `{unknown_metric, Registry, Name}` error if histogram with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_histogram.html#observe_n/5"},{"type":"function","title":"prometheus_histogram.pobserve/6","doc":"Observes the given `Value`, `Count` times, in the bucket position of the bucket list.\n\nUseful when the bucket position is known in advance, as it avoids having to compute such value\nduring the observation.","ref":"prometheus_histogram.html#pobserve/6"},{"type":"function","title":"prometheus_histogram.remove/1","doc":"","ref":"prometheus_histogram.html#remove/1"},{"type":"function","title":"prometheus_histogram.remove/2","doc":"","ref":"prometheus_histogram.html#remove/2"},{"type":"function","title":"prometheus_histogram.remove/3","doc":"Removes histogram series identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if histogram with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_histogram.html#remove/3"},{"type":"function","title":"prometheus_histogram.reset/1","doc":"","ref":"prometheus_histogram.html#reset/1"},{"type":"function","title":"prometheus_histogram.reset/2","doc":"","ref":"prometheus_histogram.html#reset/2"},{"type":"function","title":"prometheus_histogram.reset/3","doc":"Resets the value of the histogram identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if histogram with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_histogram.html#reset/3"},{"type":"function","title":"prometheus_histogram.value/1","doc":"","ref":"prometheus_histogram.html#value/1"},{"type":"function","title":"prometheus_histogram.value/2","doc":"","ref":"prometheus_histogram.html#value/2"},{"type":"function","title":"prometheus_histogram.value/3","doc":"Returns the value of the histogram identified by `Registry`, `Name` and `LabelValues`.\nIf there is no histogram for `LabelValues`, returns `undefined`.\n\nIf duration unit set, sum will be converted to the duration unit.\n[Read more here](`m:prometheus_time`).\n\nRaises:\n\n* `{unknown_metric, Registry, Name}` error if histogram named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_histogram.html#value/3"},{"type":"function","title":"prometheus_histogram.values/2","doc":"","ref":"prometheus_histogram.html#values/2"},{"type":"module","title":"prometheus_quantile_summary","doc":"Summary metric, to track the size of events and report quantiles Based on prometheus_summary\n\nExample use cases for Summaries:\n* Response latency;\n* Request size;\n* Response size.\n\nExample:\n\n```erlang\n-module(my_proxy_instrumenter).\n\nsetup() ->\n    prometheus_quantile_summary:declare([{name, request_size_bytes},\n                                         {help, \\\"Request size in bytes.\\\"}]),\n    prometheus_quantile_summary:declare([{name, response_size_bytes},\n                                         {help, \\\"Response size in bytes.\\\"}]).\n\nobserve_request(Size) ->\n    prometheus_quantile_summary:observe(request_size_bytes, Size).\n\nobserve_response(Size) ->\n    prometheus_quantile_summary:observe(response_size_bytes, Size).\n\n```\n\nReports:\n\n```text\nrequest_size_bytes_size\nrequest_size_bytes_count\nrequest_size_bytes\\{quantile=\\\"0.5\\\"\\}\nrequest_size_bytes\\{quantile=\\\"0.9\\\"\\}\nrequest_size_bytes\\{quantile=\\\"0.95\\\"\\}\n```","ref":"prometheus_quantile_summary.html"},{"type":"module","title":"Configuration - prometheus_quantile_summary","doc":"The specs cannot have a key called `quantile`, as this key is reserved by the implementation.\n\nPassing `targets`, the quantile estimator can be fine-tuned, as in\n`quantile_estimator:f_targeted/1`. See `default_targets/0` for the default values.\n\nPassing `compress_limit` we can configure how often to run compressions into the quantile summary\nalgorithm.","ref":"prometheus_quantile_summary.html#module-configuration"},{"type":"module","title":"Notes - prometheus_quantile_summary","doc":"The underlying algorithm implemented in `m:quantile_estimator` does not support mergeability of\nsummaries, therefore a summary in this implementation is linear, that is, all updates happen on the\nsame ets record. Because of this, race conditions can imply datapoint loss.\nStatistically, this might not be relevant, but such impact is not ensured.\n\nBecause of this, support for quantile summaries is rather experimental\nand histograms are recommended instead.","ref":"prometheus_quantile_summary.html#module-notes"},{"type":"function","title":"prometheus_quantile_summary.declare/1","doc":"Creates a summary using `Spec`. If a summary with the same `Spec` exists returns `false`.\n\nRaises:\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, MessagE}` error if `duration_unit` is unknown or doesn't match metric name.","ref":"prometheus_quantile_summary.html#declare/1"},{"type":"function","title":"prometheus_quantile_summary.default_targets/0","doc":"","ref":"prometheus_quantile_summary.html#default_targets/0"},{"type":"function","title":"prometheus_quantile_summary.deregister/1","doc":"","ref":"prometheus_quantile_summary.html#deregister/1"},{"type":"function","title":"prometheus_quantile_summary.deregister/2","doc":"Removes all summary series with name `Name` and removes Metric Family from `Registry`.\n\nAfter this call new/1 for `Name` and `Registry` will succeed.\n\nReturns `{true, _}` if `Name` was a registered summary. Otherwise returns `{false, _}`.","ref":"prometheus_quantile_summary.html#deregister/2"},{"type":"function","title":"prometheus_quantile_summary.new/1","doc":"Creates a summary using `Spec`.\n\nRaises:\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, Message}` error if `duration_unit` is unknown or doesn't match metric name.\n* `{mf_already_exists, {Registry, Name}, Message}` error if a summary with the same `Spec` already exists.","ref":"prometheus_quantile_summary.html#new/1"},{"type":"function","title":"prometheus_quantile_summary.observe/2","doc":"","ref":"prometheus_quantile_summary.html#observe/2"},{"type":"function","title":"prometheus_quantile_summary.observe/3","doc":"","ref":"prometheus_quantile_summary.html#observe/3"},{"type":"function","title":"prometheus_quantile_summary.observe/4","doc":"Observes the given `Value`.\n\nRaises:\n* `{invalid_value, Value, Message}` if `Value` isn't an integer.\n* `{unknown_metric, Registry, Name}` error if summary with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_quantile_summary.html#observe/4"},{"type":"function","title":"prometheus_quantile_summary.observe_duration/2","doc":"","ref":"prometheus_quantile_summary.html#observe_duration/2"},{"type":"function","title":"prometheus_quantile_summary.observe_duration/3","doc":"","ref":"prometheus_quantile_summary.html#observe_duration/3"},{"type":"function","title":"prometheus_quantile_summary.observe_duration/4","doc":"Tracks the amount of time spent executing `Fun`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.\n* `{invalid_value, Value, Message}` if `Fun` isn't a function.","ref":"prometheus_quantile_summary.html#observe_duration/4"},{"type":"function","title":"prometheus_quantile_summary.remove/1","doc":"","ref":"prometheus_quantile_summary.html#remove/1"},{"type":"function","title":"prometheus_quantile_summary.remove/2","doc":"","ref":"prometheus_quantile_summary.html#remove/2"},{"type":"function","title":"prometheus_quantile_summary.remove/3","doc":"Removes summary series identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_quantile_summary.html#remove/3"},{"type":"function","title":"prometheus_quantile_summary.reset/1","doc":"","ref":"prometheus_quantile_summary.html#reset/1"},{"type":"function","title":"prometheus_quantile_summary.reset/2","doc":"","ref":"prometheus_quantile_summary.html#reset/2"},{"type":"function","title":"prometheus_quantile_summary.reset/3","doc":"Resets the value of the summary identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_quantile_summary.html#reset/3"},{"type":"function","title":"prometheus_quantile_summary.value/1","doc":"","ref":"prometheus_quantile_summary.html#value/1"},{"type":"function","title":"prometheus_quantile_summary.value/2","doc":"","ref":"prometheus_quantile_summary.html#value/2"},{"type":"function","title":"prometheus_quantile_summary.value/3","doc":"Returns the value of the summary identified by `Registry`, `Name` and `LabelValues`.\nIf there is no summary for `LabelValues`, returns `undefined`.\n\nIf duration unit set, sum will be converted to the duration unit.\n[Read more here](`m:prometheus_time`).\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_quantile_summary.html#value/3"},{"type":"function","title":"prometheus_quantile_summary.values/2","doc":"","ref":"prometheus_quantile_summary.html#values/2"},{"type":"module","title":"prometheus_summary","doc":"Summary metric, to track the size of events.\n\nExample use cases for Summaries:\n* Response latency;\n* Request size;\n* Response size.\n\nThis keeps track of the number of events, and the sum of their values.\nThis allows you to calculate the average value of each event,\nand with enough datapoints, to keep track of its average.\n\nExample:\n\n```erlang\n-module(my_proxy_instrumenter).\n\nsetup() ->\n    prometheus_summary:declare([{name, request_size_bytes},\n                                {help, \\\"Request size in bytes.\\\"}]),\n    prometheus_summary:declare([{name, response_size_bytes},\n                                {help, \\\"Response size in bytes.\\\"}]).\n\nobserve_request(Size) ->\n    prometheus_summary:observe(request_size_bytes, Size).\n\nobserve_response(Size) ->\n    prometheus_summary:observe(response_size_bytes, Size).\n```","ref":"prometheus_summary.html"},{"type":"function","title":"prometheus_summary.declare/1","doc":"Creates a summary using `Spec`. If a summary with the same `Spec` exists returns `false`.\n\nRaises:\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, MessagE}` error if `duration_unit` is unknown or doesn't match metric name.","ref":"prometheus_summary.html#declare/1"},{"type":"function","title":"prometheus_summary.deregister/1","doc":"","ref":"prometheus_summary.html#deregister/1"},{"type":"function","title":"prometheus_summary.deregister/2","doc":"Removes all summary series with name `Name` and removes Metric Family from `Registry`.\n\nAfter this call new/1 for `Name` and `Registry` will succeed.\n\nReturns `{true, _}` if `Name` was a registered summary. Otherwise returns `{false, _}`.","ref":"prometheus_summary.html#deregister/2"},{"type":"function","title":"prometheus_summary.new/1","doc":"Creates a summary using `Spec`.\n\nRaises:\n* `{missing_metric_spec_key, Key, Spec}` error if required `Spec` key is missing.\n* `{invalid_metric_name, Name, Message}` error if metric `Name` is invalid.\n* `{invalid_metric_help, Help, Message}` error if metric `Help` is invalid.\n* `{invalid_metric_labels, Labels, Message}` error if `Labels` isn't a list.\n* `{invalid_label_name, Name, Message}` error if `Name` isn't a valid label name.\n* `{invalid_value_error, Value, Message}` error if `duration_unit` is unknown or doesn't match metric name.\n* `{mf_already_exists, {Registry, Name}, Message}` error if a summary with the same `Spec` already exists.","ref":"prometheus_summary.html#new/1"},{"type":"function","title":"prometheus_summary.observe/2","doc":"","ref":"prometheus_summary.html#observe/2"},{"type":"function","title":"prometheus_summary.observe/3","doc":"","ref":"prometheus_summary.html#observe/3"},{"type":"function","title":"prometheus_summary.observe/4","doc":"Observes the given `Value`.\n\nRaises:\n* `{invalid_value, Value, Message}` if `Value` isn't an integer.\n* `{unknown_metric, Registry, Name}` error if summary with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_summary.html#observe/4"},{"type":"function","title":"prometheus_summary.observe_duration/2","doc":"","ref":"prometheus_summary.html#observe_duration/2"},{"type":"function","title":"prometheus_summary.observe_duration/3","doc":"","ref":"prometheus_summary.html#observe_duration/3"},{"type":"function","title":"prometheus_summary.observe_duration/4","doc":"Tracks the amount of time spent executing `Fun`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary with named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.\n* `{invalid_value, Value, Message}` if `Fun` isn't a function.","ref":"prometheus_summary.html#observe_duration/4"},{"type":"function","title":"prometheus_summary.remove/1","doc":"","ref":"prometheus_summary.html#remove/1"},{"type":"function","title":"prometheus_summary.remove/2","doc":"","ref":"prometheus_summary.html#remove/2"},{"type":"function","title":"prometheus_summary.remove/3","doc":"Removes summary series identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_summary.html#remove/3"},{"type":"function","title":"prometheus_summary.reset/1","doc":"","ref":"prometheus_summary.html#reset/1"},{"type":"function","title":"prometheus_summary.reset/2","doc":"","ref":"prometheus_summary.html#reset/2"},{"type":"function","title":"prometheus_summary.reset/3","doc":"Resets the value of the summary identified by `Registry`, `Name` and `LabelValues`.\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary with name `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_summary.html#reset/3"},{"type":"function","title":"prometheus_summary.value/1","doc":"","ref":"prometheus_summary.html#value/1"},{"type":"function","title":"prometheus_summary.value/2","doc":"","ref":"prometheus_summary.html#value/2"},{"type":"function","title":"prometheus_summary.value/3","doc":"Returns the value of the summary identified by `Registry`, `Name` and `LabelValues`.\nIf there is no summary for `LabelValues`, returns `undefined`.\n\nIf duration unit set, sum will be converted to the duration unit.\n[Read more here.](`m:prometheus_time`)\n\nRaises:\n* `{unknown_metric, Registry, Name}` error if summary named `Name` can't be found in `Registry`.\n* `{invalid_metric_arity, Present, Expected}` error if labels count mismatch.","ref":"prometheus_summary.html#value/3"},{"type":"function","title":"prometheus_summary.values/2","doc":"","ref":"prometheus_summary.html#values/2"},{"type":"module","title":"prometheus_protobuf_format","doc":"Serializes Prometheus registry using [protocol buffer format](http://bit.ly/2cxSuJP).","ref":"prometheus_protobuf_format.html"},{"type":"function","title":"prometheus_protobuf_format.content_type/0","doc":"Returns content type of the protocol buffer format.","ref":"prometheus_protobuf_format.html#content_type/0"},{"type":"function","title":"prometheus_protobuf_format.format/0","doc":"Formats `default` registry using protocol buffer format.","ref":"prometheus_protobuf_format.html#format/0"},{"type":"function","title":"prometheus_protobuf_format.format/1","doc":"Formats `Registry` using protocol buffer format.","ref":"prometheus_protobuf_format.html#format/1"},{"type":"module","title":"prometheus_text_format","doc":"Serializes Prometheus registry using the latest [text format](http://bit.ly/2cxSuJP).\n\nExample output:\n\n```text\n# TYPE http_request_duration_milliseconds histogram\n# HELP http_request_duration_milliseconds Http Request execution time\nhttp_request_duration_milliseconds_bucket{method=\\\"post\\\",le=\\\"100\\\"} 0\nhttp_request_duration_milliseconds_bucket{method=\\\"post\\\",le=\\\"300\\\"} 1\nhttp_request_duration_milliseconds_bucket{method=\\\"post\\\",le=\\\"500\\\"} 3\nhttp_request_duration_milliseconds_bucket{method=\\\"post\\\",le=\\\"750\\\"} 4\nhttp_request_duration_milliseconds_bucket{method=\\\"post\\\",le=\\\"1000\\\"} 5\nhttp_request_duration_milliseconds_bucket{method=\\\"post\\\",le=\\\"+Inf\\\"} 6\nhttp_request_duration_milliseconds_count{method=\\\"post\\\"} 6\nhttp_request_duration_milliseconds_sum{method=\\\"post\\\"} 4350\n```","ref":"prometheus_text_format.html"},{"type":"function","title":"prometheus_text_format.content_type/0","doc":"Returns content type of the latest \\[text format](http://bit.ly/2cxSuJP).","ref":"prometheus_text_format.html#content_type/0"},{"type":"function","title":"prometheus_text_format.escape_label_value/1","doc":"Escapes the backslash (\\\\), double-quote (\\\"), and line feed (\\\\n) characters","ref":"prometheus_text_format.html#escape_label_value/1"},{"type":"function","title":"prometheus_text_format.format/0","doc":"Equivalent to [format(default)](`format/1`).\n\nFormats `default` registry using the latest text format.","ref":"prometheus_text_format.html#format/0"},{"type":"function","title":"prometheus_text_format.format/1","doc":"Formats `Registry` using the latest text format.","ref":"prometheus_text_format.html#format/1"},{"type":"function","title":"prometheus_text_format.render_labels/1","doc":"","ref":"prometheus_text_format.html#render_labels/1"},{"type":"extras","title":"Overview","doc":"# Prometheus.io client for Erlang #\n\n[![Hex.pm](https://img.shields.io/hexpm/v/prometheus.svg?maxAge=2592000?style=plastic)](https://hex.pm/packages/prometheus)\n[![Hex.pm](https://img.shields.io/hexpm/dt/prometheus.svg?maxAge=2592000)](https://hex.pm/packages/prometheus)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/prometheus/)\n[![GitHub Actions](https://github.com/prometheus-erl/prometheus.erl/actions/workflows/main.yml/badge.svg)](https://github.com/prometheus-erl/prometheus.erl/actions/workflows/main.yml)\n[![Codecov](https://codecov.io/github/prometheus-erl/prometheus.erl/graph/badge.svg?token=G9HB5UKNIY)](https://codecov.io/github/prometheus-erl/prometheus.erl)\n\n[Prometheus.io](https://prometheus.io) monitoring system and time series database client in Erlang.\n\n![RabbitMQ Dashboard](https://raw.githubusercontent.com/deadtrickster/prometheus_rabbitmq_exporter/master/priv/dashboards/RabbitMQErlangVM.png)\n\n- IRC: #erlang on Freenode; \n- [Slack](https://elixir-slackin.herokuapp.com/): #prometheus channel - [Browser](https://elixir-lang.slack.com/messages/prometheus) or App(slack://elixir-lang.slack.com/messages/prometheus).","ref":"readme.html"},{"type":"extras","title":"Integrations - Overview","doc":"- [Cowboy1/2 Exporters and Cowboy2 instrumenter](https://hex.pm/packages/prometheus_cowboy)\n- [Opencensus.io integration](https://github.com/deadtrickster/opencensus-erlang-prometheus)\n- [Ecto Instrumenter](https://hex.pm/packages/prometheus_ecto)\n- [Elixir client](https://github.com/deadtrickster/prometheus.ex)\n- [Elixir plugs Instrumenters and Exporter](https://hex.pm/packages/prometheus_plugs)\n- [Extatus - App to report metrics to Prometheus from Elixir GenServers](https://github.com/gmtprime/extatus)\n- [Fuse plugin](https://github.com/jlouis/fuse#fuse_stats_prometheus)\n- [Inets HTTPD Exporter](https://github.com/deadtrickster/prometheus_httpd)\n- [OS process info Collector](https://hex.pm/packages/prometheus_process_collector) (linux, freebsd, macos)\n- [Phoenix Instrumenter](https://hex.pm/packages/prometheus_phoenix)\n- [RabbitMQ Exporter](https://github.com/deadtrickster/prometheus_rabbitmq_exporter).","ref":"readme.html#integrations"},{"type":"extras","title":"Dashboards - Overview","doc":"- [Beam Dashboards](https://github.com/deadtrickster/beam-dashboards).","ref":"readme.html#dashboards"},{"type":"extras","title":"Blogs - Overview","doc":"- [Install, Monitor Erlang Releases in Kubernetes with Helm + Prometheus](https://spacetimeinsight.com/installing-monitoring-erlang-releases-kubernetes-helm-prometheus/)\n- [Monitoring Elixir apps in 2016: Prometheus and Grafana](https://aldusleaf.org/monitoring-elixir-apps-in-2016-prometheus-and-grafana/)\n- [A Simple Erlang Application, with Prometheus](https://markbucciarelli.com/posts/2016-11-23_a_simple_erlang_application_with_prometheus.html).","ref":"readme.html#blogs"},{"type":"extras","title":"Erlang VM & OTP Collectors - Overview","doc":"- [Memory Collector](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_vm_memory_collector.md)\n- [Mnesia Collector](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_mnesia_collector.md)\n- [Statistics Collector](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_vm_statistics_collector.md)\n- [System Information Collector](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_vm_system_info_collector.md).","ref":"readme.html#erlang-vm-otp-collectors"},{"type":"extras","title":"Compatibility - Overview","doc":"","ref":"readme.html#compatibility"},{"type":"extras","title":"OTP versions - Overview","doc":"Version 3.x works on OTP18+. For older version (oldest tested is R16B03) please use\n[3.x-pre18 branch](https://github.com/deadtrickster/prometheus.erl/tree/3.x-pre18).\n3.x-pre18 will work on all OTP releases starting from R16B03 and its beam will recompile itself to accommodate.\nFor example, this branch is used by [RabbitMQ Exporter](https://github.com/deadtrickster/prometheus_rabbitmq_exporter) 3.6.x\nthat should be compatible with all versions starting from R16B03.","ref":"readme.html#otp-versions"},{"type":"extras","title":"Build tools - Overview","doc":"Rebar3 is supported.","ref":"readme.html#build-tools"},{"type":"extras","title":"Example Console Session - Overview","doc":"Run shell with compiled and loaded app:\n\n```erlang-repl\n    $ rebar3 shell\n```\n\nStart prometheus app:\n\n```erlang-repl\nprometheus:start().\n```\n\nRegister metrics:\n\n```erlang\nprometheus_gauge:new([{name, pool_size}, {help, \"MongoDB Connections pool size\"}]),\nprometheus_counter:new([{name, http_requests_total}, {help, \"Http request count\"}]).\nprometheus_summary:new([{name, orders}, {help, \"Track orders count/total sum\"}]).\nprometheus_histogram:new([{name, http_request_duration_milliseconds},\n                               {labels, [method]},\n                               {buckets, [100, 300, 500, 750, 1000]},\n                               {help, \"Http Request execution time\"}]).\n```\n\nUse metrics:\n\n```erlang\nprometheus_gauge:set(pool_size, 365),\nprometheus_counter:inc(http_requests_total).\nprometheus_summary:observe(orders, 10).\nprometheus_summary:observe(orders, 15).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 95).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 100).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 102).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 150).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 250).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 75).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 350).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 550).\nprometheus_histogram:observe(http_request_duration_milliseconds, [get], 950).\nprometheus_histogram:observe(http_request_duration_milliseconds, [post], 500),\nprometheus_histogram:observe(http_request_duration_milliseconds, [post], 150).\nprometheus_histogram:observe(http_request_duration_milliseconds, [post], 450).\nprometheus_histogram:observe(http_request_duration_milliseconds, [post], 850).\nprometheus_histogram:observe(http_request_duration_milliseconds, [post], 750).\nprometheus_histogram:observe(http_request_duration_milliseconds, [post], 1650).\n```\n\nExport metrics as text:\n\n```erlang\nio:format(prometheus_text_format:format()).\n```\n\n->\n\n```text\n# TYPE http_requests_total counter\n# HELP http_requests_total Http request count\nhttp_requests_total 2\n# TYPE pool_size gauge\n# HELP pool_size MongoDB Connections pool size\npool_size 365\n# TYPE orders summary\n# HELP orders Track orders count/total sum\norders_count 4\norders_sum 50\n# TYPE http_request_duration_milliseconds histogram\n# HELP http_request_duration_milliseconds Http Request execution time\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"100\"} 0\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"300\"} 1\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"500\"} 3\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"750\"} 4\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"1000\"} 5\nhttp_request_duration_milliseconds_bucket{method=\"post\",le=\"+Inf\"} 6\nhttp_request_duration_milliseconds_count{method=\"post\"} 6\nhttp_request_duration_milliseconds_sum{method=\"post\"} 4350\nhttp_request_duration_milliseconds_bucket{method=\"get\",le=\"100\"} 3\nhttp_request_duration_milliseconds_bucket{method=\"get\",le=\"300\"} 6\nhttp_request_duration_milliseconds_bucket{method=\"get\",le=\"500\"} 7\nhttp_request_duration_milliseconds_bucket{method=\"get\",le=\"750\"} 8\nhttp_request_duration_milliseconds_bucket{method=\"get\",le=\"1000\"} 9\nhttp_request_duration_milliseconds_bucket{method=\"get\",le=\"+Inf\"} 9\nhttp_request_duration_milliseconds_count{method=\"get\"} 9\nhttp_request_duration_milliseconds_sum{method=\"get\"} 2622\n```","ref":"readme.html#example-console-session"},{"type":"extras","title":"API - Overview","doc":"API can be grouped like this:","ref":"readme.html#api"},{"type":"extras","title":"Standard Metrics & Registry - Overview","doc":"- [`prometheus_counter`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_counter.md) - counter metric, to track counts of events or running totals;\n- [`prometheus_gauge`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_gauge.md) - gauge metric, to report instantaneous values;\n- [`prometheus_histogram`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_histogram.md) - histogram metric, to track distributions of events;\n- [`prometheus_summary`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_summary.md) - summary metric, to track the size of events;\n- [`prometheus_boolean`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_boolean.md) - boolean metric, to track the state of something;\n- [`prometheus_registry`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_registry.md) - working with Prometheus registries.\n\nAll metrics created via `new/1` or `declare/1`. The difference is that `new/1` actually wants metric to be\nnew and raises `{mf_already_exists, {Registry, Name}, Message}` error if it isn't.\n\nBoth `new/1` and `declare/1` accept options as [proplist](http://erlang.org/doc/man/proplists.html).\nCommon options are:\n\n- name - metric name, can be an atom or a string (required);\n- help - metric help, string (required);\n- labels - metric labels, label can be an atom or a string (default is []);\n- registry - Prometheus registry for the metric, can be any term. (default is default)\n\nHistogram also accepts `buckets` option. Please refer to respective modules docs for the more information.","ref":"readme.html#standard-metrics-registry"},{"type":"extras","title":"Exposition Formats - Overview","doc":"- [`prometheus_text_format`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_text_format.md) - renders metrics for a given registry (default is `default`) in text format;\n- [`prometheus_protobuf_format`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_protobuf_format.md) - renders metrics for a given registry (default is `default`) in protobuf v2 format.","ref":"readme.html#exposition-formats"},{"type":"extras","title":"General Helpers - Overview","doc":"- [`prometheus_buckets`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_buckets.md) - linear or exponential bucket generators;\n- [`prometheus_http`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_http.md) - helpers for HTTP instrumenters;\n- [`prometheus_mnesia`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_mnesia.md) - Mnesia instrumentation helpers.","ref":"readme.html#general-helpers"},{"type":"extras","title":"Advanced - Overview","doc":"You will need these modules only if you're writing a custom collector for an app/lib that can't be instrumented directly.\n\n- [`prometheus_collector`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_collector.md) - common interface for collectors;\n- [`prometheus_format`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_format.md) - common interface for exposition formats;\n- [`prometheus_model_helpers`](https://github.com/deadtrickster/prometheus.erl/blob/master/doc/prometheus_model_helpers.md) - provides API for working with underlying Prometheus models.\nYou'll use that if you want to create a custom collector.","ref":"readme.html#advanced"},{"type":"extras","title":"Build - Overview","doc":"```\n   $ rebar3 compile\n```","ref":"readme.html#build"},{"type":"extras","title":"Configuration - Overview","doc":"Prometheus.erl supports standard Erlang app configuration.\n- `collectors` - List of custom collectors modules to be registered automatically.\n    Can be `all_loaded` in order to find all modules implementing the `prometheus_collector` behaviour.\n    Supports an \"alias\" option `default`, which will append all default collectors implemented in this library.\n    If undefined, the default collectors implemented in this library will be used.\n- `instrumenters` - List of custom instrumenter modules to be registered automatically.\n    Can be `all_loaded` in order to find all modules implementing the `prometheus_instrumenter` behaviour.\n    If undefined, none will be loaded.\n- `default_metrics` - List of metrics to be registered during app startup.\n    Metric format: `{Type, Spec}` where `Type` is a metric type (counter, gauge, etc),\n    `Spec` is a list to be passed to `Metric:declare/1`.\n    Deprecated format `{Registry, Metric, Spec}` also supported.","ref":"readme.html#configuration"},{"type":"extras","title":"Collectors & Exporters Conventions - Overview","doc":"","ref":"readme.html#collectors-exporters-conventions"},{"type":"extras","title":"Configuration - Overview","doc":"All 3d-party libraries should be configured via `prometheus` app env.\n\nExporters are responsible for maintaining scrape endpoint.\nExporters are usually tightly coupled with the web server and are singletons.\nThey should understand these keys:\n - `path` - url for scraping;\n - `format` - scrape format as module name i.e. `prometheus_text_format` or `prometheus_protobuf_format`.\nExporter-specific options should be under ` _exporter` for erlang or ` Exporter` for Elixir i.e. `PlugsExporter` or `elli_exporter`\n\nCollectors collect integration specific metrics i.e. ecto timings, process information and so on.\nTheir configuration should be under ` _collector`for erlang or ` Collector` for Elixir i.e. `process_collector`, `EctoCollector` and so on.","ref":"readme.html#configuration"},{"type":"extras","title":"Naming - Overview","doc":"For Erlang: `prometheus_ _collector`/`prometheus_ _exporter`.\n\nFor Elixir: `Prometheus. Collector`/`Prometheus. Exporter`.","ref":"readme.html#naming"},{"type":"extras","title":"License","doc":"The MIT License (MIT)\n\nCopyright (c) 2016, Ilya Khaprov  .\nCopyright (c) 2025, Nelson Vides  .\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}